﻿<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:cat_ru="urn:customs.ru:CommonAggregateTypes:5.0.1" xmlns:catpi_ru="urn:customs.ru:Information:PriorInformation:PriorCommonAggregateTypes:5.0.1" xmlns:pict="urn:customs.ru:Information:PriorInformation:PI_TIRCarnet:5.0.1" exclude-result-prefixes="cat_ru catpi_ru pict">
	<xsl:template match="/">
		<xsl:apply-templates select=".//pict:PI_TIRCarnet"/>
	</xsl:template>
	<xsl:variable name="code-russia" select="'RU'"/>
	<xsl:variable name="code-presented-waybill" select="'02015'"/>
	<xsl:variable name="code-presented-invoice" select="'04021'"/>
	<xsl:key use="catpi_ru:CountryACode" name="a2code" match="pict:DispatchCountry | pict:DestinationCountry"/>
	<xsl:template match="pict:PI_TIRCarnet">
		<JTIR_XX>
			<JTIR_XX_ITEM>
				<xsl:for-each select="pict:PI_TIRShippingInfo[1]">
					<JOURNALTYPE>
						<xsl:choose>
							<xsl:when test="(pict:DispatchCountry/catpi_ru:CountryACode=$code-russia) and (pict:DestinationCountry/catpi_ru:CountryACode!=$code-russia)">
								<xsl:value-of select="0"/>
							</xsl:when>
							<xsl:when test="(pict:DispatchCountry/catpi_ru:CountryACode!=$code-russia) and (pict:DestinationCountry/catpi_ru:CountryACode=$code-russia)">
								<xsl:value-of select="1"/>
							</xsl:when>
							<xsl:when test="(pict:DispatchCountry/catpi_ru:CountryACode!=$code-russia) and (pict:DestinationCountry/catpi_ru:CountryACode!=$code-russia)">
								<xsl:value-of select="2"/>
							</xsl:when>
							<xsl:when test="(pict:DispatchCountry/catpi_ru:CountryACode=$code-russia) and (pict:DestinationCountry/catpi_ru:CountryACode=$code-russia)">
								<xsl:value-of select="3"/>
							</xsl:when>
							<!--Иначе журнал определится автоматом по журналу вызова загрузки-->
						</xsl:choose>
					</JOURNALTYPE>
					<G15C_ABC2>
						<xsl:value-of select="pict:DispatchCountry/catpi_ru:CountryACode"/>
					</G15C_ABC2>
					<G17C_ABC2>
						<xsl:value-of select="pict:DestinationCountry/catpi_ru:CountryACode"/>
					</G17C_ABC2>
				</xsl:for-each>
				<xsl:for-each select="pict:PI_TIRMDP[1]">
					<MDPLetters>
						<xsl:value-of select="catpi_ru:TIRSeries"/>
					</MDPLetters>
					<N_MDP>
						<xsl:value-of select="catpi_ru:TIRID"/>
					</N_MDP>
					<W_LIST_NO>
						<xsl:value-of select="catpi_ru:TIRWhitePageNumber"/>
					</W_LIST_NO>
					<HOLDERIDN>
						<xsl:value-of select="catpi_ru:TIRHolder"/>
					</HOLDERIDN>
				</xsl:for-each>
				<xsl:for-each select="pict:PI_TIRTotalGoods[1]">
					<G05>
						<xsl:value-of select="pict:TotalGoodsNameQuantity"/>
					</G05>
					<SPECIF_GDS>
						<xsl:value-of select="pict:ShipSpecifGoodsQuantity"/>
					</SPECIF_GDS>
					<G222>
						<xsl:value-of select="pict:TotalInvoicedCost"/>
					</G222>
					<G35_NTF>
						<xsl:value-of select="pict:TotalGrossWeight"/>
					</G35_NTF>
				</xsl:for-each>
				<xsl:if test="pict:PI_TIRShipment[1]">
					<JTIR_XX_CSGNT>
						<xsl:apply-templates select="pict:PI_TIRShipment"/>
					</JTIR_XX_CSGNT>
				</xsl:if>
				<xsl:apply-templates select="pict:PI_TIRCarrier[1]"/>
				<xsl:apply-templates select="pict:PI_TIRPrincipal[1]"/>
				<xsl:apply-templates select="pict:PI_TIRShippingInfo/pict:TransportMeans[1]"/>
				<xsl:apply-templates select="(pict:PI_TIRShipment/pict:PI_TIRDestination)[1]">
					<!--КПС ТО понимает только одно место назначения на всю декларацию, берёт из первой партии-->
				</xsl:apply-templates>
				<G504>
					<xsl:value-of select="pict:DateLimit"/>
				</G504>
				<xsl:variable name="G3161">
					<xsl:for-each select="pict:PI_TIRShipment/pict:PI_TIRGoods/catpi_ru:ContainerNumbers[not(.=preceding::catpi_ru:ContainerNumbers)]">
						<xsl:value-of select="."/>
						<xsl:if test="not(position()=last())">
							<xsl:value-of select='","'/>
						</xsl:if>
					</xsl:for-each>
				</xsl:variable>
				<xsl:if test="$G3161!=''">
					<G3161>
						<xsl:copy-of select="$G3161"/>
					</G3161>
				</xsl:if>
				<JGDS_XX>
					<xsl:apply-templates select=".//pict:PI_TIRGoods"/>
				</JGDS_XX>
				<xsl:variable name="other-presented-docs" select="pict:PI_TIRShipment/pict:PresentedDocuments[(catpi_ru:PresentedDocumentModeCode!=$code-presented-waybill) and (catpi_ru:PresentedDocumentModeCode!=$code-presented-invoice)]"/>
				<xsl:if test="$other-presented-docs[1]">
					<JTIR_XX_DOCS>
						<xsl:for-each select="$other-presented-docs[not(.=preceding::*)]">
							<JTIR_XX_DOCS_ITEM>
								<DOCCODE>
									<xsl:value-of select="catpi_ru:PresentedDocumentModeCode"/>
								</DOCCODE>
								<DOCNUM>
									<xsl:value-of select="cat_ru:PrDocumentNumber"/>
								</DOCNUM>
								<DOCDATE>
									<xsl:value-of select="cat_ru:PrDocumentDate"/>
								</DOCDATE>
							</JTIR_XX_DOCS_ITEM>
						</xsl:for-each>
					</JTIR_XX_DOCS>
				</xsl:if>
			</JTIR_XX_ITEM>
		</JTIR_XX>
	</xsl:template>
	<xsl:template match="pict:PI_TIRCarrier">
		<G501>
			<xsl:value-of select="cat_ru:OrganizationName"/>
		</G501>
		<xsl:apply-templates select="cat_ru:RFOrganizationFeatures[1]"/>
		<xsl:for-each select="pict:Address[1]">
			<xsl:call-template name="Address">
				<xsl:with-param name="name-of-CountryCode" select="'DRIVE_ABC2'"/>
				<xsl:with-param name="name-of-PostalCode" select="'CARRIER_POSTALCODE'"/>
				<xsl:with-param name="name-of-Region" select="'CARRIER_REGION'"/>
				<xsl:with-param name="name-of-City" select="'CARRIER_CITY'"/>
				<xsl:with-param name="name-of-StreetHouse" select="'CARRIER_STREETHOUSE'"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:apply-templates select="pict:DriverInformation[1]"/>
	</xsl:template>
	<xsl:template match="pict:DriverInformation">
		<xsl:for-each select="cat_ru:PersonSurname">
			<DRIVERSURNAME>
				<xsl:value-of select="."/>
			</DRIVERSURNAME>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:PersonName">
			<DRIVERNAME>
				<xsl:value-of select="."/>
			</DRIVERNAME>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:PersonMiddleName">
			<DRIVERMIDNAME>
				<xsl:value-of select="."/>
			</DRIVERMIDNAME>
		</xsl:for-each>
		<xsl:apply-templates select="catpi_ru:IdentityCard[1]"/>
	</xsl:template>
	<xsl:template match="catpi_ru:IdentityCard">
		<xsl:choose>
			<xsl:when test="ancestor::pict:DriverInformation">
				<xsl:for-each select="cat_ru:IdentityCardCode">
					<CARRIERPERSCARDCODE>
						<xsl:value-of select="."/>
					</CARRIERPERSCARDCODE>
				</xsl:for-each>
				<xsl:for-each select="cat_ru:IdentityCardName">
					<CARRIERPERSCARDNAME>
						<xsl:value-of select="."/>
					</CARRIERPERSCARDNAME>
				</xsl:for-each>
				<xsl:for-each select="cat_ru:IdentityCardSeries">
					<CARRIERPERSCARDSERIES>
						<xsl:value-of select="."/>
					</CARRIERPERSCARDSERIES>
				</xsl:for-each>
				<xsl:for-each select="cat_ru:IdentityCardNumber">
					<CARRIERPERSCARDNUM>
						<xsl:value-of select="."/>
					</CARRIERPERSCARDNUM>
				</xsl:for-each>
				<xsl:for-each select="cat_ru:IdentityCardDate">
					<CARRIERPERSCARDDATE>
						<xsl:value-of select="."/>
					</CARRIERPERSCARDDATE>
				</xsl:for-each>
				<xsl:for-each select="cat_ru:OrganizationName">
					<CARRIERPERSCARDORG>
						<xsl:value-of select="."/>
					</CARRIERPERSCARDORG>
				</xsl:for-each>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="pict:PI_TIRPrincipal">
		<FAGENTNAME>
			<xsl:value-of select="cat_ru:OrganizationName"/>
		</FAGENTNAME>
		<xsl:for-each select="pict:Address[1]">
			<xsl:call-template name="Address">
				<xsl:with-param name="name-of-CountryCode" select="'PRINC_COUNTRYCODE'"/>
				<xsl:with-param name="name-of-PostalCode" select="'PRINC_POSTALCODE'"/>
				<xsl:with-param name="name-of-Region" select="'PRINC_REGION'"/>
				<xsl:with-param name="name-of-City" select="'PRINC_CITY'"/>
				<xsl:with-param name="name-of-StreetHouse" select="'PRINC_STREETHOUSE'"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="pict:TransportMeans">
		<xsl:for-each select="catpi_ru:TransportModeCode[.!=''][1]">
			<G26>
				<xsl:value-of select="."/>
			</G26>
		</xsl:for-each>
		<xsl:for-each select="catpi_ru:TransportMeansNationalityCode[.!=''][1]">
			<TC_ABC2>
				<xsl:value-of select="."/>
			</TC_ABC2>
		</xsl:for-each>
		<xsl:for-each select="catpi_ru:TransportIdentifier[.!=''][1]">
			<N_TR>
				<xsl:value-of select="."/>
			</N_TR>
		</xsl:for-each>
		<xsl:for-each select="catpi_ru:VINID[.!=''][1]">
			<VIN>
				<xsl:value-of select="."/>
			</VIN>
		</xsl:for-each>
		<xsl:for-each select="catpi_ru:TrailerIdentifier[.!=''][1]">
			<N_TRAILER>
				<xsl:value-of select="."/>
			</N_TRAILER>
		</xsl:for-each>
		<xsl:for-each select="catpi_ru:SecondTrailerIdentifier[.!=''][1]">
			<N_TRAILER2>
				<xsl:value-of select="."/>
			</N_TRAILER2>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="pict:PI_TIRDestination">
		<xsl:for-each select="pict:DestinationCustoms/cat_ru:Code[.!=''][1]">
			<G531>
				<xsl:value-of select="."/>
			</G531>
			<GA3>
				<xsl:value-of select="."/>
			</GA3>
		</xsl:for-each>
		<xsl:for-each select="pict:Address[1]">
			<xsl:call-template name="Address">
				<xsl:with-param name="name-of-CountryCode" select="'DEST_COUNTRYCODE'"/>
				<xsl:with-param name="name-of-PostalCode" select="'DEST_POSTALCODE'"/>
				<xsl:with-param name="name-of-Region" select="'DEST_REGION'"/>
				<xsl:with-param name="name-of-City" select="'DEST_CITY'"/>
				<xsl:with-param name="name-of-StreetHouse" select="'DEST_STREETHOUSE'"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="pict:DestinationWarehouse[1]">
			<A_NLIC>
				<xsl:value-of select="catpi_ru:CertificateNumber"/>
			</A_NLIC>
			<A_DLIC>
				<xsl:value-of select="catpi_ru:CertificateDate"/>
			</A_DLIC>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="pict:PI_TIRGoods">
		<JGDS_XX_ITEM>
			<G32>
				<xsl:choose>
					<xsl:when test="string(number(catpi_ru:GoodsNumeric))!='NaN'">
						<xsl:value-of select="catpi_ru:GoodsNumeric"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="position()"/>
					</xsl:otherwise>
				</xsl:choose>
			</G32>
			<N_RECEIVER>
				<xsl:value-of select="1"/>
			</N_RECEIVER>
			<G33>
				<xsl:value-of select="catpi_ru:GoodsTNVEDCode"/>
			</G33>
			<G312>
				<xsl:value-of select="catpi_ru:GoodsDescription"/>
			</G312>
			<G35>
				<xsl:value-of select="catpi_ru:GrossWeightQuantity"/>
			</G35>
			<NetWeight>
				<xsl:value-of select="catpi_ru:NetWeightQuantity"/>
			</NetWeight>
			<xsl:for-each select="catpi_ru:GoodsPackaging[1]">
				<G311>
					<xsl:value-of select="catpi_ru:PakageQuantity"/>
				</G311>
				<G318>
					<xsl:value-of select="catpi_ru:CargoCode"/>
				</G318>
			</xsl:for-each>
			<G42>
				<xsl:value-of select="catpi_ru:InvoicedCost"/>
			</G42>
			<G221_BUK>
				<xsl:value-of select="catpi_ru:CurrencyCode"/>
			</G221_BUK>
			<xsl:for-each select="catpi_ru:GoodsMeasureQuantity[1]">
				<G315>
					<xsl:value-of select="catpi_ru:GoodsQuantity"/>
				</G315>
				<G317C>
					<xsl:value-of select="catpi_ru:MeasureUnitQualifierCode"/>
				</G317C>
			</xsl:for-each>
			<KODS_PT>
				<xsl:value-of select="catpi_ru:OriginCountryCode"/>
			</KODS_PT>
			<N_TTH>
				<xsl:call-template name="presented-waybill">
					<xsl:with-param name="node-shipment" select=".."/>
				</xsl:call-template>
			</N_TTH>
			<xsl:for-each select="../pict:PresentedDocuments[catpi_ru:PresentedDocumentModeCode=$code-presented-invoice][1]">
				<InvoiceNum>
					<xsl:value-of select="cat_ru:PrDocumentNumber"/>
				</InvoiceNum>
				<InvoiceDate>
					<xsl:value-of select="cat_ru:PrDocumentDate"/>
				</InvoiceDate>
			</xsl:for-each>
		</JGDS_XX_ITEM>
	</xsl:template>
	<xsl:template name="presented-waybill">
		<xsl:param name="node-shipment"/>
		<xsl:value-of select="$node-shipment/pict:PresentedDocuments[catpi_ru:PresentedDocumentModeCode=$code-presented-waybill][1]/cat_ru:PrDocumentNumber"/>
	</xsl:template>
	<xsl:template match="pict:PI_TIRShipment">
		<JTIR_XX_CSGNT_ITEM>
			<N_TD>
				<xsl:call-template name="presented-waybill">
					<xsl:with-param name="node-shipment" select="."/>
				</xsl:call-template>
			</N_TD>
			<xsl:for-each select="pict:PI_TIRConsignor[1]">
				<G022>
					<xsl:value-of select="cat_ru:OrganizationName"/>
				</G022>
				<xsl:apply-templates select="cat_ru:RFOrganizationFeatures[1]"/>
				<xsl:for-each select="pict:Address[1]">
					<xsl:call-template name="Address">
						<xsl:with-param name="name-of-CountryCode" select="'CSGNOR_COUNTRYCODE'"/>
						<xsl:with-param name="name-of-PostalCode" select="'CSGNOR_POSTALCODE'"/>
						<xsl:with-param name="name-of-Region" select="'CSGNOR_REGION'"/>
						<xsl:with-param name="name-of-City" select="'CSGNOR_CITY'"/>
						<xsl:with-param name="name-of-StreetHouse" select="'CSGNOR_STREETHOUSE'"/>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:for-each>
			<xsl:for-each select="pict:PI_TIRConsignee[1]">
				<G082>
					<xsl:value-of select="cat_ru:OrganizationName"/>
				</G082>
				<xsl:apply-templates select="cat_ru:RFOrganizationFeatures[1]"/>
				<xsl:for-each select="pict:Address[1]">
					<xsl:call-template name="Address">
						<xsl:with-param name="name-of-CountryCode" select="'CSGNEE_COUNTRYCODE'"/>
						<xsl:with-param name="name-of-PostalCode" select="'CSGNEE_POSTALCODE'"/>
						<xsl:with-param name="name-of-Region" select="'CSGNEE_REGION'"/>
						<xsl:with-param name="name-of-City" select="'CSGNEE_CITY'"/>
						<xsl:with-param name="name-of-StreetHouse" select="'CSGNEE_STREETHOUSE'"/>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:for-each>
		</JTIR_XX_CSGNT_ITEM>
	</xsl:template>
	<xsl:template match="cat_ru:RFOrganizationFeatures">
		<xsl:choose>
			<xsl:when test="ancestor::pict:PI_TIRCarrier">
				<DRIVEROGRN>
					<xsl:value-of select="cat_ru:OGRN"/>
				</DRIVEROGRN>
				<INN_DRIVER>
					<xsl:value-of select="cat_ru:INN"/>
				</INN_DRIVER>
				<KPP_DRIVER>
					<xsl:value-of select="cat_ru:KPP"/>
				</KPP_DRIVER>
			</xsl:when>
			<xsl:when test="ancestor::pict:PI_TIRConsignor">
				<OGRN>
					<xsl:value-of select="cat_ru:OGRN"/>
				</OGRN>
				<INN>
					<xsl:value-of select="cat_ru:INN"/>
				</INN>
				<KPP>
					<xsl:value-of select="cat_ru:KPP"/>
				</KPP>
			</xsl:when>
			<xsl:when test="ancestor::pict:PI_TIRConsignee">
				<OGRNR>
					<xsl:value-of select="cat_ru:OGRN"/>
				</OGRNR>
				<INNR>
					<xsl:value-of select="cat_ru:INN"/>
				</INNR>
				<KPP_RECEIV>
					<xsl:value-of select="cat_ru:KPP"/>
				</KPP_RECEIV>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Address">
		<xsl:param name="name-of-CountryCode"/>
		<xsl:param name="name-of-PostalCode"/>
		<xsl:param name="name-of-Region"/>
		<xsl:param name="name-of-City"/>
		<xsl:param name="name-of-StreetHouse"/>
		<xsl:for-each select="catpi_ru:CountryCode[.!=''][1]">
			<xsl:element name="{$name-of-CountryCode}">
				<xsl:value-of select="."/>
			</xsl:element>
		</xsl:for-each>
		<xsl:for-each select="catpi_ru:PostalCode[.!=''][1]">
			<xsl:element name="{$name-of-PostalCode}">
				<xsl:value-of select="."/>
			</xsl:element>
		</xsl:for-each>
		<xsl:for-each select="catpi_ru:Region[.!=''][1]">
			<xsl:element name="{$name-of-Region}">
				<xsl:value-of select="."/>
			</xsl:element>
		</xsl:for-each>
		<xsl:for-each select="catpi_ru:City[.!=''][1]">
			<xsl:element name="{$name-of-City}">
				<xsl:value-of select="."/>
			</xsl:element>
		</xsl:for-each>
		<xsl:for-each select="catpi_ru:StreetHouse[.!=''][1]">
			<xsl:element name="{$name-of-StreetHouse}">
				<xsl:value-of select="."/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="FormatDate">
		<xsl:param name="DateTime"/>
		<!-- 2007-12-27T00:00:00+01:00-->
		<!--ddMMyy-->
		<xsl:value-of select="substring($DateTime,9,2)"/>
		<xsl:value-of select="'.'"/>
		<xsl:value-of select="substring($DateTime,6,2)"/>
		<xsl:value-of select="'.'"/>
		<xsl:value-of select="substring($DateTime,3,2)"/>
	</xsl:template>
</xsl:stylesheet>
