<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:tirc="urn:customs.ru:Information:TransportDocuments:Car:CUTIR_Carnet:5.4.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:cat_ru="urn:customs.ru:CommonAggregateTypes:5.4.0" xmlns:catTrans_cu="urn:customs.ru:Information:TransportDocuments:CUTransportCommonAgregateTypesCust:5.4.0" exclude-result-prefixes="tirc cat_ru catTrans_cu">
	<xsl:import href="template-vtdecl.xsl"/>
	<xsl:import href="template-country.xsl"/>
	<xsl:import href="template-customs.xsl"/>
	<xsl:import href="template-tir.xsl"/>
	<xsl:variable name="consignment-number-from-tks">
		<xsl:value-of select="/tirc:CUTIR_Carnet/tirc:CUPresentedDocuments[tirc:PresentedDocumentModeCode=$code-presented-waybill][1]/cat_ru:PrDocumentNumber"/>
		<!--выгрузка из программы ТКС содержит накладную только в общем списке документов, без привязки к конкретной партии-->
	</xsl:variable>
	<xsl:template match="*|/">
		<xsl:apply-templates select=".//tirc:CUTIR_Carnet"/>
	</xsl:template>
	<xsl:template match="tirc:CUTIR_Carnet">
		<JTIR_XX>
			<JTIR_XX_ITEM>
				<xsl:copy-of select="$FORMXML"/>
				<JOURNALTYPE>
					<xsl:choose>
						<xsl:when test="tirc:TransitDirectionCode='ЭК'">
							<xsl:value-of select="0"/>
						</xsl:when>
						<xsl:when test="tirc:TransitDirectionCode='ИМ'">
							<xsl:value-of select="1"/>
						</xsl:when>
						<xsl:when test="tirc:TransitDirectionCode='ТР'">
							<xsl:value-of select="2"/>
						</xsl:when>
						<xsl:when test="tirc:TransitDirectionCode='ПР' or tirc:TransitDirectionCode='ТС' or tirc:TransitDirectionCode='ВТ'">
							<xsl:value-of select="3"/>
						</xsl:when>
						<!--Иначе журнал определится автоматом по журналу вызова загрузки-->
					</xsl:choose>
				</JOURNALTYPE>
				<MDPLetters>
					<xsl:value-of select="tirc:TIRIdentifier/catTrans_cu:TIRSeries"/>
				</MDPLetters>
				<N_MDP>
					<xsl:value-of select="tirc:TIRIdentifier/catTrans_cu:TIRID"/>
				</N_MDP>
				<W_LIST_NO>
					<xsl:value-of select="tirc:TIRIdentifier/catTrans_cu:TIRWhitePageNumber"/>
				</W_LIST_NO>
				<HOLDERIDN>
					<xsl:value-of select=".//tirc:TIRHolderID"/>
				</HOLDERIDN>
				<G05>
					<xsl:value-of select="tirc:GoodsQuantity"/>
				</G05>
				<G221_BUK>
					<xsl:value-of select="tirc:InvoicedCostCurrencyCode"/>
				</G221_BUK>
				<G222>
					<xsl:value-of select="tirc:TotalInvoicedCost"/>
				</G222>
				<NLIST>
					<xsl:value-of select="tirc:TotalPageQuantity"/>
				</NLIST>
				<xsl:if test="tirc:TIRShipment[1]">
					<JTIR_XX_CSGNT>
						<xsl:apply-templates select="tirc:TIRShipment"/>
					</JTIR_XX_CSGNT>
				</xsl:if>
				<xsl:if test="tirc:DispatchCountryCode!=''">
					<G15C_ABC2>
						<xsl:value-of select="tirc:DispatchCountryCode"/>
					</G15C_ABC2>
				</xsl:if>
				<xsl:if test="tirc:DestinationCountryCode!=''">
					<G17C_ABC2>
						<xsl:value-of select="tirc:DestinationCountryCode"/>
					</G17C_ABC2>
				</xsl:if>
				<xsl:for-each select="tirc:DateExpectedArrival[1]">
					<PIARRIVALDATE>
						<xsl:value-of select="."/>
					</PIARRIVALDATE>
				</xsl:for-each>
				<xsl:for-each select="tirc:TimeExpectedArrival[1]">
					<PIARRIVALTIME>
						<xsl:value-of select="."/>
					</PIARRIVALTIME>
				</xsl:for-each>
				<xsl:for-each select="tirc:BorderCustoms[1]">
					<xsl:for-each select="cat_ru:Code[1]">
						<PIARRIVALPLACECODE>
							<xsl:value-of select="."/>
						</PIARRIVALPLACECODE>
					</xsl:for-each>
					<xsl:for-each select="cat_ru:CustomsCountryCode[1]">
						<PIARRIVALCOUNTRYCODE>
							<xsl:call-template name="CountryCodeABC2">
								<xsl:with-param name="Code" select="."/>
							</xsl:call-template>
						</PIARRIVALCOUNTRYCODE>
					</xsl:for-each>
				</xsl:for-each>
				<xsl:apply-templates select="tirc:Carrier[1]"/>
				<xsl:apply-templates select="tirc:Forwarder[1]"/>
				<xsl:apply-templates select="tirc:CUTransport"/>
				<xsl:apply-templates select="tirc:TIRShipment/tirc:Destination[1]">
					<!--КПС ТО понимает только одно место назначения на всю декларацию, берёт из первой партии-->
				</xsl:apply-templates>
				<xsl:variable name="G3161">
					<xsl:for-each select="tirc:TIRShipment/tirc:ContainerID[not(.=preceding::tirc:ContainerID)]">
						<xsl:value-of select="."/>
						<xsl:if test="not(position()=last())">
							<xsl:value-of select='","'/>
						</xsl:if>
					</xsl:for-each>
				</xsl:variable>
				<xsl:if test="$G3161!=''">
					<G3161>
						<xsl:copy-of select="$G3161"/>
					</G3161>
				</xsl:if>
				<JGDS_XX>
					<xsl:apply-templates select=".//tirc:TIRGoods"/>
				</JGDS_XX>
				<xsl:variable name="other-presented-docs" select="tirc:CUPresentedDocuments[(tirc:PresentedDocumentModeCode!=$code-presented-waybill) and (tirc:PresentedDocumentModeCode!=$code-presented-invoice)]"/>
				<xsl:if test="$other-presented-docs[1]">
					<JTIR_XX_DOCS>
						<xsl:for-each select="$other-presented-docs[not(.=preceding::*)]">
							<JTIR_XX_DOCS_ITEM>
								<DOCCODE>
									<xsl:value-of select="tirc:PresentedDocumentModeCode"/>
								</DOCCODE>
								<DOCNUM>
									<xsl:value-of select="cat_ru:PrDocumentNumber"/>
								</DOCNUM>
								<DOCDATE>
									<xsl:value-of select="cat_ru:PrDocumentDate"/>
								</DOCDATE>
							</JTIR_XX_DOCS_ITEM>
						</xsl:for-each>
					</JTIR_XX_DOCS>
				</xsl:if>
			</JTIR_XX_ITEM>
		</JTIR_XX>
	</xsl:template>
	<xsl:template match="tirc:Carrier">
		<G501>
			<xsl:value-of select="cat_ru:OrganizationName"/>
		</G501>
		<xsl:apply-templates select="cat_ru:RFOrganizationFeatures[1]"/>
		<xsl:for-each select="cat_ru:Address[1]">
			<xsl:call-template name="Address">
				<xsl:with-param name="name-of-CountryCode" select="'DRIVE_ABC2'"/>
				<xsl:with-param name="name-of-PostalCode" select="'CARRIER_POSTALCODE'"/>
				<xsl:with-param name="name-of-Region" select="'CARRIER_REGION'"/>
				<xsl:with-param name="name-of-City" select="'CARRIER_CITY'"/>
				<xsl:with-param name="name-of-StreetHouse" select="'CARRIER_STREETHOUSE'"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:apply-templates select="tirc:CUDriverInformation[1]"/>
	</xsl:template>
	<xsl:template match="tirc:CUDriverInformation">
		<xsl:for-each select="cat_ru:PersonSurname">
			<DRIVERSURNAME>
				<xsl:value-of select="."/>
			</DRIVERSURNAME>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:PersonName">
			<DRIVERNAME>
				<xsl:value-of select="."/>
			</DRIVERNAME>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:PersonMiddleName">
			<DRIVERMIDNAME>
				<xsl:value-of select="."/>
			</DRIVERMIDNAME>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:RegCountryCode">
			<DRIVERPERSCOUNTRY>
				<xsl:value-of select="."/>
			</DRIVERPERSCOUNTRY>
		</xsl:for-each>
		<xsl:apply-templates select="cat_ru:IdentityCard[1]"/>
	</xsl:template>
	<xsl:template match="cat_ru:IdentityCard">
		<xsl:choose>
			<xsl:when test="ancestor::tirc:CUDriverInformation">
				<xsl:for-each select="cat_ru:IdentityCardCode">
					<CARRIERPERSCARDCODE>
						<xsl:value-of select="."/>
					</CARRIERPERSCARDCODE>
				</xsl:for-each>
				<xsl:for-each select="cat_ru:IdentityCardName">
					<CARRIERPERSCARDNAME>
						<xsl:value-of select="."/>
					</CARRIERPERSCARDNAME>
				</xsl:for-each>
				<xsl:for-each select="cat_ru:IdentityCardSeries">
					<CARRIERPERSCARDSERIES>
						<xsl:value-of select="."/>
					</CARRIERPERSCARDSERIES>
				</xsl:for-each>
				<xsl:for-each select="cat_ru:IdentityCardNumber">
					<CARRIERPERSCARDNUM>
						<xsl:value-of select="."/>
					</CARRIERPERSCARDNUM>
				</xsl:for-each>
				<xsl:for-each select="cat_ru:IdentityCardDate">
					<CARRIERPERSCARDDATE>
						<xsl:value-of select="."/>
					</CARRIERPERSCARDDATE>
				</xsl:for-each>
				<xsl:for-each select="cat_ru:OrganizationName">
					<CARRIERPERSCARDORG>
						<xsl:value-of select="."/>
					</CARRIERPERSCARDORG>
				</xsl:for-each>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="tirc:Forwarder">
		<FAGENTNAME>
			<xsl:value-of select="catTrans_cu:Name"/>
		</FAGENTNAME>
		<xsl:for-each select="catTrans_cu:Address[1]">
			<xsl:call-template name="Address">
				<xsl:with-param name="name-of-CountryCode" select="'PRINC_COUNTRYCODE'"/>
				<xsl:with-param name="name-of-PostalCode" select="'PRINC_POSTALCODE'"/>
				<xsl:with-param name="name-of-Region" select="'PRINC_REGION'"/>
				<xsl:with-param name="name-of-City" select="'PRINC_CITY'"/>
				<xsl:with-param name="name-of-StreetHouse" select="'PRINC_STREETHOUSE'"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="tirc:CUTransport">
		<xsl:for-each select="cat_ru:TransportModeCode[.!=''][1]">
			<G26>
				<xsl:value-of select="."/>
			</G26>
		</xsl:for-each>
		<xsl:for-each select="(cat_ru:TransportNationalityCode[.!=''] | tirc:TransportMeans/cat_ru:TransportMeansNationalityCode[.!=''])[1]">
			<TC_ABC2>
				<xsl:value-of select="."/>
			</TC_ABC2>
		</xsl:for-each>
		<xsl:variable name="ActiveTransportMeans" select="tirc:TransportMeans[cat_ru:ActiveTransportIdentifier[.='' or .=../cat_ru:TransportIdentifier] or not(cat_ru:ActiveTransportIdentifier) or not(cat_ru:TransportIdentifier)][1]"/>
		<xsl:for-each select="$ActiveTransportMeans">
			<xsl:call-template name="tirc:TransportMeans">
				<xsl:with-param name="name-of-Identifier" select="'N_TR'"/>
				<xsl:with-param name="name-of-VIN" select="'VIN'"/>
				<xsl:with-param name="name-of-Kind" select="'TRANSPORTKINDCODE'"/>
				<xsl:with-param name="name-of-Mark" select="'TRANSPORTMARKCODE'"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:variable name="TrailerTransportMeans" select="tirc:TransportMeans[cat_ru:ActiveTransportIdentifier=$ActiveTransportMeans/cat_ru:TransportIdentifier]"/>
		<xsl:for-each select="$TrailerTransportMeans[1]">
			<xsl:call-template name="tirc:TransportMeans">
				<xsl:with-param name="name-of-Identifier" select="'N_TRAILER'"/>
				<xsl:with-param name="name-of-VIN" select="'VIN1'"/>
				<xsl:with-param name="name-of-Kind" select="'TRANSPORTKINDCODE1'"/>
				<xsl:with-param name="name-of-Mark" select="'TRANSPORTMARKCODE1'"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="$TrailerTransportMeans[2]">
			<xsl:call-template name="tirc:TransportMeans">
				<xsl:with-param name="name-of-Identifier" select="'N_TRAILER2'"/>
				<xsl:with-param name="name-of-VIN" select="'VIN2'"/>
				<xsl:with-param name="name-of-Kind" select="'TRANSPORTKINDCODE2'"/>
				<xsl:with-param name="name-of-Mark" select="'TRANSPORTMARKCODE2'"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="tirc:TransportMeans">
		<xsl:param name="name-of-Identifier"/>
		<xsl:param name="name-of-VIN"/>
		<xsl:param name="name-of-Kind"/>
		<xsl:param name="name-of-Mark"/>
		<xsl:for-each select="cat_ru:TransportIdentifier[.!=''][1]">
			<xsl:element name="{$name-of-Identifier}">
				<xsl:value-of select="."/>
			</xsl:element>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:VIN[.!=''][1]">
			<xsl:element name="{$name-of-VIN}">
				<xsl:value-of select="."/>
			</xsl:element>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:TransportKindCode[.!=''][1]">
			<xsl:element name="{$name-of-Kind}">
				<xsl:value-of select="."/>
			</xsl:element>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:TransportMarkCode[.!=''][1]">
			<xsl:element name="{$name-of-Mark}">
				<xsl:value-of select="."/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="tirc:Destination">
		<xsl:for-each select="catTrans_cu:DestinationCustomsCode[.!=''][1]">
			<G531>
				<xsl:value-of select="."/>
			</G531>
		</xsl:for-each>
		<xsl:for-each select="catTrans_cu:DeliveryCustomsPostCode[.!=''][1]">
			<GA3>
				<xsl:value-of select="."/>
			</GA3>
		</xsl:for-each>
		<xsl:for-each select="catTrans_cu:Address[.!=''][1]">
			<xsl:call-template name="Address">
				<xsl:with-param name="name-of-CountryCode" select="'DEST_COUNTRYCODE'"/>
				<xsl:with-param name="name-of-PostalCode" select="'DEST_POSTALCODE'"/>
				<xsl:with-param name="name-of-Region" select="'DEST_REGION'"/>
				<xsl:with-param name="name-of-City" select="'DEST_CITY'"/>
				<xsl:with-param name="name-of-StreetHouse" select="'DEST_STREETHOUSE'"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="tirc:TIRGoods">
		<JGDS_XX_ITEM>
			<G32>
				<xsl:choose>
					<xsl:when test="string(number(tirc:GoodsNumeric))!='NaN'">
						<xsl:value-of select="tirc:GoodsNumeric"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="position()"/>
					</xsl:otherwise>
				</xsl:choose>
			</G32>
			<N_RECEIVER>
				<xsl:value-of select="1"/>
			</N_RECEIVER>
			<G33>
				<xsl:value-of select="tirc:GoodsTNVEDCode"/>
			</G33>
			<G312>
				<xsl:for-each select="tirc:GoodsDescription">
					<xsl:value-of select="."/>
				</xsl:for-each>
			</G312>
			<G35>
				<xsl:value-of select="tirc:GrossWeightQuantity"/>
			</G35>
			<xsl:for-each select="(tirc:PlacesInfo | tirc:PackingInfo)[1]">
				<G311>
					<xsl:value-of select="catTrans_cu:PakingQuantity"/>
				</G311>
				<G318>
					<xsl:value-of select="catTrans_cu:PackingCode"/>
				</G318>
			</xsl:for-each>
			<G42>
				<xsl:value-of select="tirc:InvoicedCost"/>
			</G42>
			<G315>
				<xsl:value-of select="tirc:SupplementaryGoodsQuantity"/>
			</G315>
			<G317C>
				<xsl:value-of select="tirc:SupplementaryMeasureUnitCode"/>
			</G317C>
			<G40>
				<xsl:value-of select="tirc:PrecedingDocumentNumber"/>
				<xsl:choose>
					<xsl:when test="tirc:PrecedingDocumentNumber!=''">
						<xsl:value-of select="tirc:PrecedingDocumentNumber"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="../../tirc:PrecedingDocument[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</G40>
			<G40T>
				<xsl:value-of select="../../tirc:PrecedingDocument[1]/tirc:DocumentKind"/>
			</G40T>
			<KODS_PT>
				<xsl:value-of select="tirc:OriginCountryCode"/>
			</KODS_PT>
			<N_TTH>
				<xsl:call-template name="consignment-number">
					<xsl:with-param name="TIRGoods" select="."/>
				</xsl:call-template>
			</N_TTH>
			<xsl:for-each select="/tirc:CUTIR_Carnet/tirc:CUPresentedDocuments[tirc:PresentedDocumentModeCode=$code-presented-invoice][1]">
				<InvoiceNum>
					<xsl:value-of select="cat_ru:PrDocumentNumber"/>
				</InvoiceNum>
				<InvoiceDate>
					<xsl:value-of select="cat_ru:PrDocumentDate"/>
				</InvoiceDate>
			</xsl:for-each>
		</JGDS_XX_ITEM>
	</xsl:template>
	<xsl:template match="tirc:PrecedingDocument">
		<xsl:call-template name="customs-number-encode">
			<xsl:with-param name="part-code" select="tirc:PrecedingDocumentCustomsCode"/>
			<xsl:with-param name="part-date" select="tirc:PrecedingDocumentDate"/>
			<xsl:with-param name="part-number" select="tirc:PrecedingDocumentNumber"/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="consignment-number">
		<xsl:param name="TIRGoods"/>
		<xsl:variable name="from-kpspi">
			<xsl:value-of select="$TIRGoods/tirc:TTNNumber[1]"/>
			<!--считаем, что во всех товарах партии одинаковый номер накладной - как в RNTS КПС "Транзитные операции" АСКТТ-2-->
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="string-length($from-kpspi)">
				<xsl:value-of select="$from-kpspi"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$consignment-number-from-tks"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="tirc:TIRShipment">
		<JTIR_XX_CSGNT_ITEM>
			<N_TD>
				<xsl:call-template name="consignment-number">
					<xsl:with-param name="TIRGoods" select="tirc:TIRGoods"/>
				</xsl:call-template>
			</N_TD>
			<xsl:for-each select="tirc:TIRConsignor[1]">
				<G022>
					<xsl:value-of select="cat_ru:OrganizationName"/>
				</G022>
				<xsl:apply-templates select="cat_ru:RFOrganizationFeatures[1]"/>
				<xsl:for-each select="cat_ru:Address[1]">
					<xsl:call-template name="Address">
						<xsl:with-param name="name-of-CountryCode" select="'CSGNOR_COUNTRYCODE'"/>
						<xsl:with-param name="name-of-PostalCode" select="'CSGNOR_POSTALCODE'"/>
						<xsl:with-param name="name-of-Region" select="'CSGNOR_REGION'"/>
						<xsl:with-param name="name-of-City" select="'CSGNOR_CITY'"/>
						<xsl:with-param name="name-of-StreetHouse" select="'CSGNOR_STREETHOUSE'"/>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:for-each>
			<xsl:for-each select="tirc:TIRConsignee[1]">
				<G082>
					<xsl:value-of select="cat_ru:OrganizationName"/>
				</G082>
				<xsl:apply-templates select="cat_ru:RFOrganizationFeatures[1]"/>
				<xsl:for-each select="cat_ru:Address[1]">
					<xsl:call-template name="Address">
						<xsl:with-param name="name-of-CountryCode" select="'CSGNEE_COUNTRYCODE'"/>
						<xsl:with-param name="name-of-PostalCode" select="'CSGNEE_POSTALCODE'"/>
						<xsl:with-param name="name-of-Region" select="'CSGNEE_REGION'"/>
						<xsl:with-param name="name-of-City" select="'CSGNEE_CITY'"/>
						<xsl:with-param name="name-of-StreetHouse" select="'CSGNEE_STREETHOUSE'"/>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:for-each>
		</JTIR_XX_CSGNT_ITEM>
	</xsl:template>
	<xsl:template match="cat_ru:RFOrganizationFeatures">
		<xsl:choose>
			<xsl:when test="ancestor::tirc:Carrier">
				<DRIVEROGRN>
					<xsl:value-of select="cat_ru:OGRN"/>
				</DRIVEROGRN>
				<INN_DRIVER>
					<xsl:value-of select="cat_ru:INN"/>
				</INN_DRIVER>
				<KPP_DRIVER>
					<xsl:value-of select="cat_ru:KPP"/>
				</KPP_DRIVER>
			</xsl:when>
			<xsl:when test="ancestor::tirc:TIRConsignor">
				<OGRN>
					<xsl:value-of select="cat_ru:OGRN"/>
				</OGRN>
				<INN>
					<xsl:value-of select="cat_ru:INN"/>
				</INN>
				<KPP>
					<xsl:value-of select="cat_ru:KPP"/>
				</KPP>
			</xsl:when>
			<xsl:when test="ancestor::tirc:TIRConsignee">
				<OGRNR>
					<xsl:value-of select="cat_ru:OGRN"/>
				</OGRNR>
				<INNR>
					<xsl:value-of select="cat_ru:INN"/>
				</INNR>
				<KPP_RECEIV>
					<xsl:value-of select="cat_ru:KPP"/>
				</KPP_RECEIV>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Address">
		<xsl:param name="name-of-CountryCode"/>
		<xsl:param name="name-of-PostalCode"/>
		<xsl:param name="name-of-Region"/>
		<xsl:param name="name-of-City"/>
		<xsl:param name="name-of-StreetHouse"/>
		<xsl:for-each select="cat_ru:CountryCode[.!=''][1]">
			<xsl:element name="{$name-of-CountryCode}">
				<xsl:value-of select="."/>
			</xsl:element>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:PostalCode[.!=''][1]">
			<xsl:element name="{$name-of-PostalCode}">
				<xsl:value-of select="."/>
			</xsl:element>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:Region[.!=''][1]">
			<xsl:element name="{$name-of-Region}">
				<xsl:value-of select="."/>
			</xsl:element>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:City[.!=''][1]">
			<xsl:element name="{$name-of-City}">
				<xsl:value-of select="."/>
			</xsl:element>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:StreetHouse[.!=''][1]">
			<xsl:element name="{$name-of-StreetHouse}">
				<xsl:value-of select="."/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="FormatDate">
		<xsl:param name="DateTime"/>
		<!-- 2007-12-27T00:00:00+01:00-->
		<!--ddMMyy-->
		<xsl:value-of select="substring($DateTime,9,2)"/>
		<xsl:value-of select="'.'"/>
		<xsl:value-of select="substring($DateTime,6,2)"/>
		<xsl:value-of select="'.'"/>
		<xsl:value-of select="substring($DateTime,3,2)"/>
	</xsl:template>
</xsl:stylesheet>
