<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:import href="template-vtdecl.xsl"/>
	<xsl:import href="template-country.xsl"/>
	<xsl:import href="template-currency.xsl"/>
	<xsl:import href="template-tir.xsl"/>
	<xsl:output method="xml"/>
	<xsl:key name="GTD44" match="GTD44_ITEM" use="concat(G441, ':::', G442, ':::', G443)"/>
	<xsl:template match="*|/">
		<xsl:apply-templates select="//ALLDOCUMENTS"/>
	</xsl:template>
	<xsl:template match="ALLDOCUMENTS">
		<JTIR_XX>
			<JTIR_XX_ITEM>
				<xsl:copy-of select="$FORMXML"/>
				<xsl:variable name="G011">
					<xsl:value-of select="//G011[1]"/>
				</xsl:variable>
				<JOURNALTYPE>
					<xsl:variable name="JOURNALTYPE-export">
						<xsl:value-of select="0"/>
					</xsl:variable>
					<xsl:variable name="JOURNALTYPE-import">
						<xsl:value-of select="1"/>
					</xsl:variable>
					<xsl:variable name="JOURNALTYPE-transit">
						<xsl:value-of select="2"/>
					</xsl:variable>
					<xsl:choose>
						<xsl:when test="$G011='ЭК'">
							<xsl:value-of select="$JOURNALTYPE-export"/>
						</xsl:when>
						<xsl:when test="$G011='ИМ'">
							<xsl:value-of select="$JOURNALTYPE-import"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$JOURNALTYPE-transit"/>
						</xsl:otherwise>
					</xsl:choose>
				</JOURNALTYPE>
				<G011>
					<xsl:value-of select="$G011"/>
				</G011>
				<xsl:for-each select="//GTD44_ITEM[G441=$code-presented-tir][1]/G442">
					<xsl:variable name="tir-num-length">
						<xsl:value-of select="8"/>
					</xsl:variable>
					<xsl:variable name="tir-num-start">
						<xsl:value-of select="1 + ( string-length(.) - $tir-num-length )"/>
					</xsl:variable>
					<N_MDP>
						<xsl:value-of select="substring( ., $tir-num-start, $tir-num-length )"/>
					</N_MDP>
					<MDPLETTERS>
						<xsl:if test="$tir-num-start > 1">
							<xsl:value-of select="substring( ., 1, $tir-num-start - 1 )"/>
						</xsl:if>
					</MDPLETTERS>
				</xsl:for-each>
				<G05>
					<xsl:value-of select="//G05"/>
				</G05>
				<G3161>
					<xsl:value-of select="//G3161"/>
				</G3161>
				<G15>
					<xsl:value-of select="//G15"/>
				</G15>
				<G15C_ABC2>
					<xsl:value-of select="//G15A"/>
				</G15C_ABC2>
				<G17B>
					<xsl:value-of select="//G17B"/>
				</G17B>
				<G17C_ABC2>
					<xsl:value-of select="//G17A"/>
				</G17C_ABC2>
				<xsl:choose>
					<xsl:when test="//G181!=''">
						<G181>
							<xsl:value-of select="//G181"/>
						</G181>
						<G182_ABC2>
							<xsl:value-of select="//G182"/>
						</G182_ABC2>
						<G183>
							<xsl:value-of select="//G180"/>
						</G183>
					</xsl:when>
					<xsl:otherwise>
						<G181>
							<xsl:value-of select="//G211"/>
						</G181>
						<G182_ABC2>
							<xsl:value-of select="//G212"/>
						</G182_ABC2>
						<G183>
							<xsl:value-of select="//G210"/>
						</G183>
					</xsl:otherwise>
				</xsl:choose>
				<TC_ABC2>
					<xsl:value-of select="//G182"/>
				</TC_ABC2>
				<xsl:variable name="GTDDKD_ITEM" select="//GTDDKD_ITEM[NGR='18']"/>
				<N_TR>
					<xsl:for-each select="$GTDDKD_ITEM[ 0 = string-length(NTRANS_PRIMARY) ]">
						<xsl:sort select="NGR" data-type="number"/>
						<xsl:sort select="CNT" data-type="number"/>
						<xsl:value-of select="NTRANS"/>
						<xsl:if test="position() != last()">
							<xsl:value-of select="','"/>
						</xsl:if>
					</xsl:for-each>
				</N_TR>
				<xsl:variable name="GTDDKD_ITEM-trailer" select="$GTDDKD_ITEM[ string-length(NTRANS_PRIMARY) != 0 ]"/>
				<N_TRAILER>
					<xsl:for-each select="$GTDDKD_ITEM-trailer[1]">
						<xsl:sort select="NGR" data-type="number"/>
						<xsl:sort select="CNT" data-type="number"/>
						<xsl:value-of select="NTRANS"/>
					</xsl:for-each>
				</N_TRAILER>
				<N_TRAILER2>
					<xsl:for-each select="$GTDDKD_ITEM-trailer[position() > 1]">
						<xsl:sort select="NGR" data-type="number"/>
						<xsl:sort select="CNT" data-type="number"/>
						<xsl:value-of select="NTRANS"/>
						<xsl:if test="position() != last()">
							<xsl:value-of select="','"/>
						</xsl:if>
					</xsl:for-each>
				</N_TRAILER2>
				<G183>
					<xsl:value-of select="//G180"/>
				</G183>
				<G26>
					<xsl:value-of select="//G251"/>
				</G26>
				<G542>
					<xsl:value-of select="//G542"/>
				</G542>
				<FAGENTNAME>
					<xsl:value-of select="//G142"/>
				</FAGENTNAME>
				<PRINC_POSTALCODE>
					<xsl:value-of select="//G143POST"/>
				</PRINC_POSTALCODE>
				<PRINC_REGION>
					<xsl:value-of select="//G143SUBD"/>
				</PRINC_REGION>
				<PRINC_CITY>
					<xsl:value-of select="//G143CITY"/>
				</PRINC_CITY>
				<PRINC_STREETHOUSE>
					<xsl:value-of select="//G143STREET"/>
				</PRINC_STREETHOUSE>
				<PRINC_COUNTRYCODE>
					<xsl:call-template name="CountryNamedAbc2">
						<xsl:with-param name="Name" select="//G1431N"/>
						<xsl:with-param name="DefaultValue" select="//G1431"/>
					</xsl:call-template>
				</PRINC_COUNTRYCODE>
				<G3161>
					<xsl:for-each select="//GTDCONT_ITEM[ISBACKSIDE=string(true())]">
						<xsl:sort select="G32" data-type="number"/>
						<xsl:sort select="CNT" data-type="number"/>
						<xsl:value-of select="CONTAINER"/>
						<xsl:if test="position()!=last()">
							<xsl:value-of select="','"/>
						</xsl:if>
					</xsl:for-each>
				</G3161>
				<JGDS_XX>
					<xsl:variable name="G221_BUK">
						<xsl:call-template name="currency-ABBR">
							<xsl:with-param name="Code" select="//G221"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:for-each select="//DECLDOP_ITEM">
						<JGDS_XX_ITEM>
							<G32>
								<xsl:value-of select="G32"/>
							</G32>
							<G33>
								<xsl:value-of select="G33"/>
							</G33>
							<G312>
								<xsl:call-template name="concat-delimited">
									<xsl:with-param name="string1" select="G312"/>
									<xsl:with-param name="delimiter1">
										<xsl:text>&#xd;&#xa;</xsl:text>
									</xsl:with-param>
									<xsl:with-param name="string2">
										<xsl:for-each select="//GTDBACK_ITEM[GRAPH_NO='31']">
											<xsl:sort select="CNT" data-type="number"/>
											<xsl:value-of select="TEXT"/>
											<xsl:if test="position()!=last()">
												<xsl:text>&#xd;&#xa;</xsl:text>
											</xsl:if>
										</xsl:for-each>
									</xsl:with-param>
								</xsl:call-template>
							</G312>
							<G311>
								<xsl:value-of select="G311"/>
							</G311>
							<G318>
								<xsl:value-of select="G313"/>
							</G318>
							<KODS_ABC2>
								<xsl:value-of select="G34"/>
							</KODS_ABC2>
							<G35>
								<xsl:value-of select="G35"/>
							</G35>
							<NETWEIGHT>
								<xsl:value-of select="G38"/>
							</NETWEIGHT>
							<G315>
								<xsl:value-of select="G315A"/>
							</G315>
							<G317C>
								<xsl:value-of select="G41A"/>
							</G317C>
							<G42>
								<xsl:value-of select="G42"/>
							</G42>
							<G221_BUK>
								<xsl:value-of select="$G221_BUK"/>
							</G221_BUK>
							<xsl:for-each select="GTD44/GTD44_ITEM[G441=$code-presented-waybill][1]">
								<N_TTH>
									<xsl:apply-templates mode="CSGNT-number" select="."/>
								</N_TTH>
							</xsl:for-each>
							<xsl:for-each select="GTD44/GTD44_ITEM[G441=$code-presented-invoice][1]">
								<INVOICENUM>
									<xsl:value-of select="G442"/>
								</INVOICENUM>
								<INVOICEDATE>
									<xsl:value-of select="G443"/>
								</INVOICEDATE>
							</xsl:for-each>
						</JGDS_XX_ITEM>
					</xsl:for-each>
				</JGDS_XX>
				<xsl:variable name="CSGNOR-and-CSGNEE">
					<G022>
						<xsl:value-of select="//G022"/>
					</G022>
					<CSGNOR_POSTALCODE>
						<xsl:value-of select="//G023POST"/>
					</CSGNOR_POSTALCODE>
					<CSGNOR_REGION>
						<xsl:value-of select="//G023SUBD"/>
					</CSGNOR_REGION>
					<CSGNOR_CITY>
						<xsl:value-of select=".//G023CITY"/>
					</CSGNOR_CITY>
					<CSGNOR_STREETHOUSE>
						<xsl:value-of select=".//G023STREET"/>
					</CSGNOR_STREETHOUSE>
					<CSGNOR_COUNTRYCODE>
						<xsl:call-template name="CountryNamedAbc2">
							<xsl:with-param name="Name" select=".//G0231N"/>
							<xsl:with-param name="DefaultValue" select=".//G0231"/>
						</xsl:call-template>
					</CSGNOR_COUNTRYCODE>
					<INN>
						<xsl:value-of select=".//M021"/>
					</INN>
					<KPP>
						<xsl:value-of select=".//G027"/>
					</KPP>
					<OGRN>
						<xsl:value-of select=".//G020"/>
					</OGRN>
					<G082>
						<xsl:value-of select=".//G082"/>
					</G082>
					<CSGNEE_POSTALCODE>
						<xsl:value-of select=".//G083POST"/>
					</CSGNEE_POSTALCODE>
					<CSGNEE_REGION>
						<xsl:value-of select=".//G083SUBD"/>
					</CSGNEE_REGION>
					<CSGNEE_CITY>
						<xsl:value-of select=".//G083CITY"/>
					</CSGNEE_CITY>
					<CSGNEE_STREETHOUSE>
						<xsl:value-of select=".//G083STREET"/>
					</CSGNEE_STREETHOUSE>
					<CSGNEE_COUNTRYCODE>
						<xsl:call-template name="CountryNamedAbc2">
							<xsl:with-param name="Name" select=".//G0831N"/>
							<xsl:with-param name="DefaultValue" select=".//G0831"/>
						</xsl:call-template>
					</CSGNEE_COUNTRYCODE>
					<INNR>
						<xsl:value-of select=".//M081"/>
					</INNR>
					<KPP_RECEIV>
						<xsl:value-of select=".//G087"/>
					</KPP_RECEIV>
					<OGRNR>
						<xsl:value-of select=".//G080"/>
					</OGRNR>
				</xsl:variable>
				<JTIR_XX_CSGNT>
					<xsl:for-each select=".//DECLDOP_ITEM/GTD44/GTD44_ITEM[G441=$code-presented-waybill][generate-id(.)=generate-id(key('GTD44', concat(G441, ':::', G442, ':::', G443))[1])]">
						<xsl:sort select="G32" data-type="number"/>
						<xsl:sort select="DOC_NUM" data-type="number"/>
						<xsl:sort select="G4402" data-type="number"/>
						<xsl:sort select="CNT" data-type="number"/>
						<JTIR_XX_CSGNT_ITEM>
							<N_TD>
								<xsl:apply-templates mode="CSGNT-number" select="."/>
							</N_TD>
							<xsl:copy-of select="$CSGNOR-and-CSGNEE"/>
						</JTIR_XX_CSGNT_ITEM>
					</xsl:for-each>
				</JTIR_XX_CSGNT>
				<JTIR_XX_DOCS>
					<xsl:for-each select=".//DECLDOP_ITEM/GTD44/GTD44_ITEM[ not(G441=$code-presented-waybill) and not(G441=$code-presented-tir) and not(G441=$code-presented-invoice) ][generate-id(.)=generate-id(key('GTD44', concat(G441, ':::', G442, ':::', G443))[1])]">
						<xsl:sort select="G32" data-type="number"/>
						<xsl:sort select="DOC_NUM" data-type="number"/>
						<xsl:sort select="G4402" data-type="number"/>
						<xsl:sort select="CNT" data-type="number"/>
						<JTIR_XX_DOCS_ITEM>
							<DOCCODE>
								<xsl:value-of select="G441"/>
							</DOCCODE>
							<DOCNUM>
								<xsl:value-of select="G442"/>
							</DOCNUM>
							<DOCDATE>
								<xsl:value-of select="G443"/>
							</DOCDATE>
						</JTIR_XX_DOCS_ITEM>
					</xsl:for-each>
				</JTIR_XX_DOCS>
			</JTIR_XX_ITEM>
		</JTIR_XX>
	</xsl:template>
	<xsl:template match="GTD44_ITEM" mode="CSGNT-number">
		<xsl:value-of select="G442"/>
	</xsl:template>
</xsl:stylesheet>
