<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ESADout_CU="urn:customs.ru:Information:CustomsDocuments:ESADout_CU:5.6.0" xmlns:cat_ru="urn:customs.ru:CommonAggregateTypes:5.6.0" xmlns:catESAD_cu="urn:customs.ru:CUESADCommonAggregateTypesCust:5.6.0" xmlns:ivt="urn:customs.ru:Information:CustomsDocuments:Inventory:5.6.0">
	<xsl:import href="template-vtdecl.xsl"/>
	<xsl:import href="template-country.xsl"/>
	<xsl:import href="template-customs.xsl"/>
	<xsl:template match="*|/">
		<xsl:apply-templates select="//ESADout_CU:ESADout_CU"/>
	</xsl:template>
	<xsl:template match="ESADout_CU:ESADout_CU">
		<VTTPRIM>
			<VTTPRIM_ITEM>
				<xsl:copy-of select="$FORMXML"/>
				<G01MPO>
					<xsl:value-of select="ESADout_CU:TransitFeature"/>
				</G01MPO>
				<xsl:for-each select="ESADout_CU:CustomsProcedure[1]">
					<xsl:choose>
						<xsl:when test="string-length(ESADout_CU:TransitDirectionCode[1])=0">
							<!--значит это ГТД, а не транзитная декларация, раз не заполнен TransitDirectionCode. И значение идёт в G011. Но пусть она загружается в открытый журнал, иначе графа 1 не будет соответствовать журналу или будет ошибочной (например, МТТ ЭК).
							<G011>
								<xsl:value-of select="."/>
							</G011>-->
						</xsl:when>
						<xsl:otherwise>
							<G011>
								<xsl:value-of select="ESADout_CU:TransitDirectionCode[1]"/>
							</G011>
							<G0131>
								<xsl:value-of select="."/>
							</G0131>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
				<TYPEBTT>
					<xsl:choose>
						<xsl:when test="ESADout_CU:TransitDirectionCode='ЭК'">
							<xsl:value-of select="ESADout_CU:TransitDirectionCode"/>
						</xsl:when>
						<xsl:when test="ESADout_CU:TransitDirectionCode='ИМ'">
							<xsl:value-of select="ESADout_CU:TransitDirectionCode"/>
						</xsl:when>
						<xsl:when test="ESADout_CU:TransitDirectionCode='ТР'">
							<xsl:value-of select="ESADout_CU:TransitDirectionCode"/>
						</xsl:when>
						<xsl:when test="ESADout_CU:TransitDirectionCode='ПР'">
							<xsl:value-of select="ESADout_CU:TransitDirectionCode"/>
						</xsl:when>
						<xsl:when test="ESADout_CU:TransitDirectionCode='ТС' or ESADout_CU:TransitDirectionCode='ВТ'">
							<xsl:value-of select="'ПР'"/>
						</xsl:when>
						<!--Иначе это не транзитная декларация, журнал определится автоматом по журналу вызова загрузки-->
					</xsl:choose>
				</TYPEBTT>
				<xsl:variable name="SealNumber-per-NUM_PLOM" select="2"/>
				<xsl:variable name="NUM_PLOM-set" select="ESADout_CU:SealNumber[position() &lt; ($SealNumber-per-NUM_PLOM +1) ]"/>
				<xsl:variable name="GTDBACK-NUM_PLOM">
					<xsl:for-each select="ESADout_CU:SealNumber[position() > $SealNumber-per-NUM_PLOM]">
						<GTDBACK_ITEM>
							<G32>
								<xsl:value-of select="'1'"/>
							</G32>
							<GRAPH_NO>
								<xsl:value-of select="'D'"/>
							</GRAPH_NO>
							<REFFIELDNAME>
								<xsl:value-of select="'NUM_PLOM'"/>
							</REFFIELDNAME>
							<TEXT>
								<xsl:value-of select="."/>
							</TEXT>
						</GTDBACK_ITEM>
					</xsl:for-each>
				</xsl:variable>
				<xsl:if test="$NUM_PLOM-set">
					<NUM_PLOM>
						<xsl:for-each select="$NUM_PLOM-set">
							<xsl:value-of select="."/>
							<xsl:if test="position()!=last()">
								<xsl:text>,</xsl:text>
							</xsl:if>
						</xsl:for-each>
					</NUM_PLOM>
				</xsl:if>
				<xsl:variable name="G032">
					<xsl:value-of select="ESADout_CU:ESADout_CUGoodsShipment[1]/catESAD_cu:TotalSheetNumber[1]"/>
				</xsl:variable>
				<xsl:variable name="Consigment" select="ESADout_CU:ESADout_CUGoodsShipment[1]/ESADout_CU:ESADout_CUConsigment[1]"/>
				<xsl:variable name="DepartureArrivalTransport" select="$Consigment/ESADout_CU:ESADout_CUDepartureArrivalTransport[1]"/>
				<xsl:variable name="DepartureArrival-ActiveTransportMeans" select="$DepartureArrivalTransport/ESADout_CU:TransportMeans[cat_ru:ActiveTransportIdentifier[.='' or .=../cat_ru:TransportIdentifier] or not(cat_ru:ActiveTransportIdentifier) or not(cat_ru:TransportIdentifier)]"/>
				<xsl:variable name="DepartureArrival-TrailerTransportMeans" select="$DepartureArrivalTransport/ESADout_CU:TransportMeans[cat_ru:ActiveTransportIdentifier=$DepartureArrival-ActiveTransportMeans/cat_ru:TransportIdentifier]"/>
				<xsl:variable name="BorderTransport" select="$Consigment/ESADout_CU:ESADout_CUBorderTransport[1]"/>
				<xsl:variable name="Border-ActiveTransportMeans" select="$BorderTransport/ESADout_CU:TransportMeans[cat_ru:ActiveTransportIdentifier[.='' or .=../cat_ru:TransportIdentifier] or not(cat_ru:ActiveTransportIdentifier) or not(cat_ru:TransportIdentifier)]"/>
				<xsl:variable name="Border-TrailerTransportMeans" select="$BorderTransport/ESADout_CU:TransportMeans[cat_ru:ActiveTransportIdentifier=$Border-ActiveTransportMeans/cat_ru:TransportIdentifier]"/>
				<xsl:for-each select="ESADout_CU:ExecutionPlace[1]">
					<G541>
						<xsl:value-of select="."/>
					</G541>
				</xsl:for-each>
				<xsl:for-each select="ESADout_CU:RailwayStationCode[1]">
					<RAILWAYST>
						<xsl:value-of select="."/>
					</RAILWAYST>
				</xsl:for-each>
				<xsl:for-each select="ESADout_CU:ExecutionDate[1]">
					<G542>
						<xsl:value-of select="."/>
					</G542>
				</xsl:for-each>
				<xsl:for-each select="ESADout_CU:ESADout_CUGoodsShipment[1]">
					<xsl:for-each select="catESAD_cu:TotalGoodsNumber[1]">
						<G05>
							<xsl:value-of select="."/>
						</G05>
					</xsl:for-each>
					<xsl:for-each select="catESAD_cu:TotalPackageNumber[1]">
						<G06>
							<xsl:value-of select="."/>
						</G06>
					</xsl:for-each>
					<xsl:if test="string-length($G032)!=0">
						<G032>
							<xsl:value-of select="$G032"/>
						</G032>
					</xsl:if>
					<xsl:apply-templates select="//ESADout_CU:ESADout_CUConsignor"/>
					<xsl:apply-templates select="//ESADout_CU:ESADout_CUConsignee"/>
					<xsl:apply-templates select="//ESADout_CU:ESADout_CUDeclarant"/>
					<xsl:for-each select="ESADout_CU:ESADout_CUCarrier[1]">
						<xsl:for-each select="cat_ru:RFOrganizationFeatures[1]/cat_ru:OGRN[1]">
							<DRIVEROGRN>
								<xsl:value-of select="."/>
							</DRIVEROGRN>
						</xsl:for-each>
						<xsl:for-each select="cat_ru:RFOrganizationFeatures[1]/cat_ru:INN[1]">
							<INN_DRIVER>
								<xsl:value-of select="."/>
							</INN_DRIVER>
						</xsl:for-each>
						<xsl:for-each select="cat_ru:RFOrganizationFeatures[1]/cat_ru:KPP[1]">
							<KPP_DRIVER>
								<xsl:value-of select="."/>
							</KPP_DRIVER>
						</xsl:for-each>
						<xsl:for-each select="cat_ru:OrganizationName[1]">
							<G501>
								<xsl:value-of select="."/>
							</G501>
						</xsl:for-each>
						<xsl:for-each select="cat_ru:Address[1]">
							<xsl:for-each select="cat_ru:City[1]">
								<G14_CITY>
									<xsl:value-of select="."/>
								</G14_CITY>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:CountryCode[1]">
								<G14_COUNTRYCODE>
									<xsl:value-of select="."/>
								</G14_COUNTRYCODE>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:CounryName[1]">
								<G14_COUNTRYNAME>
									<xsl:value-of select="."/>
								</G14_COUNTRYNAME>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:PostalCode[1]">
								<G14_POSTALCODE>
									<xsl:value-of select="."/>
								</G14_POSTALCODE>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:Region[1]">
								<G14_REGION>
									<xsl:value-of select="."/>
								</G14_REGION>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:StreetHouse[1]">
								<G14_STREETHOUSE>
									<xsl:value-of select="."/>
								</G14_STREETHOUSE>
							</xsl:for-each>
						</xsl:for-each>
						<xsl:for-each select="cat_ru:IdentityCard">
							<xsl:for-each select="cat_ru:IdentityCardCode[1]">
								<G14_PERSCARDCODE>
									<xsl:value-of select="."/>
								</G14_PERSCARDCODE>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:IdentityCardName[1]">
								<G14_PERSCARDNAME>
									<xsl:value-of select="."/>
								</G14_PERSCARDNAME>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:IdentityCardSeries[1]">
								<G14_PERSCARDSERIES>
									<xsl:value-of select="."/>
								</G14_PERSCARDSERIES>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:IdentityCardNumber[1]">
								<G14_PERSCARDNUM>
									<xsl:value-of select="."/>
								</G14_PERSCARDNUM>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:IdentityCardDate[1]">
								<G14_PERSCARDDATE>
									<xsl:value-of select="."/>
								</G14_PERSCARDDATE>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:OrganizationName[1]">
								<G14_PERSCARDORG>
									<xsl:value-of select="."/>
								</G14_PERSCARDORG>
							</xsl:for-each>
						</xsl:for-each>
					</xsl:for-each>
					<xsl:for-each select="$Consigment[1]">
						<xsl:for-each select="catESAD_cu:ContainerIndicator[1]">
							<G19>
								<xsl:call-template name="boolean-from-string"/>
							</G19>
						</xsl:for-each>
						<xsl:for-each select="catESAD_cu:DispatchCountryCode[1]">
							<G15C_ABC2>
								<xsl:value-of select="."/>
							</G15C_ABC2>
						</xsl:for-each>
						<xsl:for-each select="catESAD_cu:DispatchCountryName[1]">
							<G15>
								<xsl:value-of select="."/>
							</G15>
						</xsl:for-each>
						<xsl:for-each select="catESAD_cu:DestinationCountryCode[1]">
							<G17C_ABC2>
								<xsl:value-of select="."/>
							</G17C_ABC2>
						</xsl:for-each>
						<xsl:for-each select="catESAD_cu:DestinationCountryName[1]">
							<G17B>
								<xsl:value-of select="."/>
							</G17B>
						</xsl:for-each>
						<xsl:for-each select="ESADout_CU:DateExpectedArrival[1]">
							<PIARRIVALDATE>
								<xsl:value-of select="."/>
							</PIARRIVALDATE>
						</xsl:for-each>
						<xsl:for-each select="ESADout_CU:TimeExpectedArrival[1]">
							<PIARRIVALTIME>
								<xsl:value-of select="."/>
							</PIARRIVALTIME>
						</xsl:for-each>
						<xsl:for-each select="ESADout_CU:DeliveryCustomsOffice[1]">
							<xsl:for-each select="cat_ru:Code[1]">
								<G531>
									<xsl:value-of select="."/>
								</G531>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:OfficeName[1]">
								<G53>
									<xsl:value-of select="."/>
								</G53>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:CustomsCountryCode[1]">
								<DELIVERYCUSTOMSCOUNTRYCODE>
									<xsl:call-template name="CountryCodeABC2">
										<xsl:with-param name="Code" select="."/>
									</xsl:call-template>
								</DELIVERYCUSTOMSCOUNTRYCODE>
							</xsl:for-each>
						</xsl:for-each>
						<xsl:for-each select="ESADout_CU:PPBorderCustoms[1]">
							<xsl:for-each select="cat_ru:Code[1]">
								<PIARRIVALPLACECODE>
									<xsl:value-of select="."/>
								</PIARRIVALPLACECODE>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:CustomsCountryCode[1]">
								<PIARRIVALCOUNTRYCODE>
									<xsl:call-template name="CountryCodeABC2">
										<xsl:with-param name="Code" select="."/>
									</xsl:call-template>
								</PIARRIVALCOUNTRYCODE>
							</xsl:for-each>
						</xsl:for-each>
						<xsl:for-each select="$DepartureArrivalTransport[1]">
							<xsl:for-each select="cat_ru:TransportModeCode[1]">
								<G251>
									<xsl:value-of select="."/>
								</G251>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:TransportNationalityCode[1]">
								<G182_ABC2>
									<xsl:value-of select="."/>
								</G182_ABC2>
							</xsl:for-each>
							<xsl:for-each select="ESADout_CU:TransportMeansQuantity[1]">
								<G183>
									<xsl:value-of select="."/>
								</G183>
							</xsl:for-each>
							<xsl:for-each select="$DepartureArrival-ActiveTransportMeans[1]">
								<xsl:for-each select="cat_ru:TransportIdentifier[1]">
									<G181>
										<xsl:value-of select="."/>
									</G181>
								</xsl:for-each>
								<xsl:for-each select="cat_ru:VIN[1]">
									<VIN>
										<xsl:value-of select="."/>
									</VIN>
								</xsl:for-each>
							</xsl:for-each>
							<xsl:for-each select="$DepartureArrival-TrailerTransportMeans[1]">
								<xsl:for-each select="cat_ru:TransportIdentifier[1]">
									<TRAILER>
										<xsl:value-of select="."/>
									</TRAILER>
								</xsl:for-each>
								<xsl:for-each select="cat_ru:VIN[1]">
									<VIN1>
										<xsl:value-of select="."/>
									</VIN1>
								</xsl:for-each>
							</xsl:for-each>
							<xsl:for-each select="$DepartureArrival-TrailerTransportMeans[2]">
								<xsl:for-each select="cat_ru:TransportIdentifier[1]">
									<TRAILER2>
										<xsl:value-of select="."/>
									</TRAILER2>
								</xsl:for-each>
								<xsl:for-each select="cat_ru:VIN[1]">
									<VIN2>
										<xsl:value-of select="."/>
									</VIN2>
								</xsl:for-each>
							</xsl:for-each>
						</xsl:for-each>
						<xsl:for-each select="$BorderTransport[1]">
							<xsl:for-each select="cat_ru:TransportModeCode[1]">
								<G26>
									<xsl:value-of select="."/>
								</G26>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:TransportNationalityCode[1]">
								<G212_ABC2>
									<xsl:value-of select="."/>
								</G212_ABC2>
							</xsl:for-each>
							<xsl:for-each select="ESADout_CU:TransportMeansQuantity[1]">
								<G213>
									<xsl:value-of select="."/>
								</G213>
							</xsl:for-each>
							<xsl:for-each select="$Border-ActiveTransportMeans[1]">
								<xsl:for-each select="cat_ru:TransportIdentifier[1]">
									<G211>
										<xsl:value-of select="."/>
									</G211>
								</xsl:for-each>
								<xsl:for-each select="cat_ru:VIN[1]">
									<PRECEDVIN>
										<xsl:value-of select="."/>
									</PRECEDVIN>
								</xsl:for-each>
							</xsl:for-each>
							<xsl:for-each select="$Border-TrailerTransportMeans[1]">
								<xsl:for-each select="cat_ru:TransportIdentifier[1]">
									<PRECEDTRAILER>
										<xsl:value-of select="."/>
									</PRECEDTRAILER>
								</xsl:for-each>
								<xsl:for-each select="cat_ru:VIN[1]">
									<PRECEDVIN1>
										<xsl:value-of select="."/>
									</PRECEDVIN1>
								</xsl:for-each>
							</xsl:for-each>
							<xsl:for-each select="$Border-TrailerTransportMeans[2]">
								<xsl:for-each select="cat_ru:TransportIdentifier[1]">
									<PRECEDTRAILER2>
										<xsl:value-of select="."/>
									</PRECEDTRAILER2>
								</xsl:for-each>
								<xsl:for-each select="cat_ru:VIN[1]">
									<PRECEDVIN2>
										<xsl:value-of select="."/>
									</PRECEDVIN2>
								</xsl:for-each>
							</xsl:for-each>
						</xsl:for-each>
					</xsl:for-each>
					<xsl:for-each select="ESADout_CU:ESADout_CUMainContractTerms[1]">
						<xsl:for-each select="catESAD_cu:ContractCurrencyCode[1]">
							<G221_BUK>
								<xsl:value-of select="."/>
							</G221_BUK>
						</xsl:for-each>
						<xsl:for-each select="catESAD_cu:TotalInvoiceAmount[1]">
							<G222>
								<xsl:value-of select="."/>
							</G222>
						</xsl:for-each>
					</xsl:for-each>
				</xsl:for-each>
				<xsl:for-each select="ESADout_CU:FilledPerson[1]">
					<xsl:for-each select="cat_ru:PersonName[1]">
						<PRINCIPALPERSNAME>
							<xsl:value-of select="."/>
						</PRINCIPALPERSNAME>
					</xsl:for-each>
					<xsl:for-each select="cat_ru:PersonMiddleName[1]">
						<PRINCIPALPERSMIDDLENAME>
							<xsl:value-of select="."/>
						</PRINCIPALPERSMIDDLENAME>
					</xsl:for-each>
					<xsl:for-each select="cat_ru:PersonSurname[1]">
						<PRINCIPALPERSSURNAME>
							<xsl:value-of select="."/>
						</PRINCIPALPERSSURNAME>
					</xsl:for-each>
					<xsl:for-each select="catESAD_cu:IdentityCard[1]">
						<xsl:for-each select="cat_ru:IdentityCardCode[1]">
							<PRINCIPALPERSCARDCODE>
								<xsl:value-of select="."/>
							</PRINCIPALPERSCARDCODE>
						</xsl:for-each>
						<xsl:for-each select="cat_ru:IdentityCardName[1]">
							<PRINCIPALPERSCARDNAME>
								<xsl:value-of select="."/>
							</PRINCIPALPERSCARDNAME>
						</xsl:for-each>
						<xsl:for-each select="cat_ru:IdentityCardSeries[1]">
							<PRINCIPALPERSCARDSERIES>
								<xsl:value-of select="."/>
							</PRINCIPALPERSCARDSERIES>
						</xsl:for-each>
						<xsl:for-each select="cat_ru:IdentityCardNumber[1]">
							<PRINCIPALPERSCARDNUM>
								<xsl:value-of select="."/>
							</PRINCIPALPERSCARDNUM>
						</xsl:for-each>
						<xsl:for-each select="cat_ru:IdentityCardDate[1]">
							<PRINCIPALPERSCARDDATE>
								<xsl:value-of select="."/>
							</PRINCIPALPERSCARDDATE>
						</xsl:for-each>
						<xsl:for-each select="cat_ru:OrganizationName[1]">
							<PRINCIPALPERSCARDORG>
								<xsl:value-of select="."/>
							</PRINCIPALPERSCARDORG>
						</xsl:for-each>
					</xsl:for-each>
					<xsl:for-each select="catESAD_cu:ExecutionDate[1]">
						<G542>
							<xsl:value-of select="."/>
						</G542>
					</xsl:for-each>
					<xsl:for-each select="ESADout_CU:ExecutionPlace[1]">
						<G541>
							<xsl:value-of select="."/>
						</G541>
					</xsl:for-each>
					<xsl:for-each select="ESADout_CU:RailwayStationCode[1]">
						<RAILWAYST>
							<xsl:value-of select="."/>
						</RAILWAYST>
					</xsl:for-each>
				</xsl:for-each>
				<xsl:variable name="default-contract-currency-code" select="ESADout_CU:ESADout_CUGoodsShipment[1]/ESADout_CU:ESADout_CUMainContractTerms[1]/catESAD_cu:ContractCurrencyCode[1]"/>
				<xsl:variable name="content-of-VTTCARRIERDRIVERS">
					<xsl:for-each select="ESADout_CU:ESADout_CUGoodsShipment/ESADout_CU:ESADout_CUCarrier/ESADout_CU:ESADout_CUDriverInformation">
						<VTTCARRIERDRIVERS_ITEM>
							<NPP>
								<xsl:value-of select="position()"/>
							</NPP>
							<xsl:for-each select="cat_ru:PersonName[1]">
								<PERSONNAME>
									<xsl:value-of select="."/>
								</PERSONNAME>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:PersonMiddleName[1]">
								<PERSONMIDNAME>
									<xsl:value-of select="."/>
								</PERSONMIDNAME>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:PersonSurname[1]">
								<PERSONSURNAME>
									<xsl:value-of select="."/>
								</PERSONSURNAME>
							</xsl:for-each>
							<xsl:for-each select="cat_ru:IdentityCard[1]">
								<xsl:for-each select="cat_ru:IdentityCardCode[1]">
									<IDENTITYCARDCODE>
										<xsl:value-of select="."/>
									</IDENTITYCARDCODE>
								</xsl:for-each>
								<xsl:for-each select="cat_ru:IdentityCardName[1]">
									<IDENTITYCARDNAME>
										<xsl:value-of select="."/>
									</IDENTITYCARDNAME>
								</xsl:for-each>
								<xsl:for-each select="cat_ru:IdentityCardSeries[1]">
									<IDENTITYCARDSERIES>
										<xsl:value-of select="."/>
									</IDENTITYCARDSERIES>
								</xsl:for-each>
								<xsl:for-each select="cat_ru:IdentityCardNumber[1]">
									<IDENTITYCARDNUMBER>
										<xsl:value-of select="."/>
									</IDENTITYCARDNUMBER>
								</xsl:for-each>
								<xsl:for-each select="cat_ru:IdentityCardDate[1]">
									<IDENTITYCARDDATE>
										<xsl:value-of select="."/>
									</IDENTITYCARDDATE>
								</xsl:for-each>
							</xsl:for-each>
						</VTTCARRIERDRIVERS_ITEM>
					</xsl:for-each>
				</xsl:variable>
				<xsl:if test="string-length($content-of-VTTCARRIERDRIVERS)!=0">
					<VTTCARRIERDRIVERS>
						<xsl:copy-of select="$content-of-VTTCARRIERDRIVERS"/>
					</VTTCARRIERDRIVERS>
				</xsl:if>
				<VTTDOP>
					<xsl:for-each select="ESADout_CU:ESADout_CUGoodsShipment/ESADout_CU:ESADout_CUGoods">
						<VTTDOP_ITEM>
							<xsl:for-each select="catESAD_cu:GoodsNumeric[1]">
								<G32>
									<xsl:value-of select="."/>
								</G32>
							</xsl:for-each>
							<xsl:if test="string-length($G032)!=0">
								<G032>
									<xsl:value-of select="$G032"/>
								</G032>
							</xsl:if>
							<G312>
								<xsl:for-each select="catESAD_cu:GoodsDescription[1]">
									<xsl:value-of select="."/>
								</xsl:for-each>
							</G312>
							<xsl:for-each select="catESAD_cu:GrossWeightQuantity[1]">
								<G35>
									<xsl:value-of select="."/>
								</G35>
							</xsl:for-each>
							<xsl:for-each select="catESAD_cu:NetWeightQuantity[1]">
								<NETTO>
									<xsl:value-of select="."/>
								</NETTO>
							</xsl:for-each>
							<xsl:for-each select="catESAD_cu:InvoicedCost[1]">
								<G42>
									<xsl:value-of select="."/>
								</G42>
							</xsl:for-each>
							<xsl:for-each select="($default-contract-currency-code | ESADout_CU:CurrencyCode[1])[position()=last()]">
								<INVCCOSTCODE>
									<xsl:value-of select="."/>
								</INVCCOSTCODE>
							</xsl:for-each>
							<xsl:for-each select="catESAD_cu:CustomsCost[1]">
								<G45>
									<xsl:value-of select="."/>
								</G45>
							</xsl:for-each>
							<xsl:for-each select="catESAD_cu:GoodsTNVEDCode[1]">
								<G33>
									<xsl:value-of select="."/>
								</G33>
							</xsl:for-each>
							<xsl:for-each select="catESAD_cu:OriginCountryCode[1]">
								<G34_ABC2>
									<xsl:value-of select="."/>
								</G34_ABC2>
							</xsl:for-each>
							<xsl:for-each select="catESAD_cu:AdditionalSheetCount[1]">
								<G031>
									<xsl:value-of select="."/>
								</G031>
							</xsl:for-each>
							<xsl:for-each select="ESADout_CU:SupplementaryGoodsQuantity[1]">
								<xsl:for-each select="cat_ru:GoodsQuantity[1]">
									<G315A>
										<xsl:value-of select="."/>
									</G315A>
								</xsl:for-each>
								<xsl:for-each select="cat_ru:MeasureUnitQualifierCode[1]">
									<G41A>
										<xsl:value-of select="."/>
									</G41A>
								</xsl:for-each>
							</xsl:for-each>
							<xsl:for-each select="ESADout_CU:ESADGoodsPackaging[1]/catESAD_cu:PakageQuantity">
								<G311>
									<xsl:value-of select="."/>
								</G311>
							</xsl:for-each>
							<VTTDOPPACK>
								<xsl:for-each select="ESADout_CU:ESADGoodsPackaging[1]/catESAD_cu:PackingInformation">
									<VTTDOPPACK_ITEM>
										<NPP>
											<xsl:value-of select="position()"/>
										</NPP>
										<xsl:for-each select="catESAD_cu:PackingCode[1]">
											<G318>
												<xsl:value-of select="."/>
											</G318>
										</xsl:for-each>
										<xsl:for-each select="catESAD_cu:PakingQuantity[1]">
											<G314>
												<xsl:value-of select="."/>
											</G314>
										</xsl:for-each>
									</VTTDOPPACK_ITEM>
								</xsl:for-each>
							</VTTDOPPACK>
							<xsl:for-each select="ESADout_CU:ESADContainer[1]">
								<xsl:for-each select="catESAD_cu:ContainerQuantity[1]">
									<G3160>
										<xsl:value-of select="."/>
									</G3160>
								</xsl:for-each>
								<G3161>
									<xsl:for-each select="catESAD_cu:ContainerNumber/catESAD_cu:ContainerIdentificaror">
										<xsl:value-of select="."/>
										<xsl:if test="position()!=last()">
											<xsl:text>,</xsl:text>
										</xsl:if>
									</xsl:for-each>
								</G3161>
							</xsl:for-each>
							<VTTDOPPRESDOCS>
								<xsl:for-each select="ESADout_CU:ESADout_CUPresentedDocument">
									<VTTDOPPRESDOCS_ITEM>
										<NPP>
											<xsl:value-of select="position()"/>
										</NPP>
										<xsl:for-each select="cat_ru:PrDocumentNumber[1]">
											<DOCNUM>
												<xsl:value-of select="."/>
											</DOCNUM>
										</xsl:for-each>
										<xsl:for-each select="cat_ru:PrDocumentDate[1]">
											<DOCDATE>
												<xsl:value-of select="."/>
											</DOCDATE>
										</xsl:for-each>
										<xsl:for-each select="catESAD_cu:PresentedDocumentModeCode[1]">
											<DOCCODE>
												<xsl:value-of select="."/>
											</DOCCODE>
										</xsl:for-each>
									</VTTDOPPRESDOCS_ITEM>
								</xsl:for-each>
							</VTTDOPPRESDOCS>
							<xsl:variable name="GTDNumber">
								<xsl:for-each select="/.//ivt:GTDNumber">
									<xsl:call-template name="customs-number-encode">
										<xsl:with-param name="part-code" select="cat_ru:CustomsCode"/>
										<xsl:with-param name="part-date" select="cat_ru:RegistrationDate"/>
										<xsl:with-param name="part-number" select="cat_ru:GTDNumber"/>
									</xsl:call-template>
								</xsl:for-each>
							</xsl:variable>
							<xsl:choose>
								<xsl:when test="string($GTDNumber)">
									<!--bug 20970 - если загрузка из таможенной декларации (ДТ, ГТД), то её номер идёт в предшествующий-->
									<PRECEDDOCTYPE>
										<xsl:value-of select="'10023'"/>
									</PRECEDDOCTYPE>
									<G40>
										<xsl:value-of select="$GTDNumber"/>
									</G40>
								</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="ESADout_CU:ESADout_CUPrecedingDocument[1]">
										<xsl:for-each select="catESAD_cu:PrecedingDocumentModeCode">
											<PRECEDDOCTYPE>
												<xsl:value-of select="."/>
											</PRECEDDOCTYPE>
										</xsl:for-each>
										<G40>
											<xsl:call-template name="customs-number-encode">
												<xsl:with-param name="part-code" select="catESAD_cu:PrecedingDocumentCustomsCode"/>
												<xsl:with-param name="part-date" select="catESAD_cu:PrecedingDocumentDate"/>
												<xsl:with-param name="part-number" select="catESAD_cu:PrecedingDocumentNumber"/>
											</xsl:call-template>
										</G40>
									</xsl:for-each>
									<xsl:if test="ESADout_CU:ESADout_CUPrecedingDocument[position()>1]">
										<GTD40>
											<xsl:for-each select="ESADout_CU:ESADout_CUPrecedingDocument[position()>1]">
												<GTD40_ITEM>
													<xsl:for-each select="catESAD_cu:PrecedingDocumentModeCode">
														<DOCCODE>
															<xsl:value-of select="."/>
														</DOCCODE>
													</xsl:for-each>
													<G402>
														<xsl:call-template name="customs-number-encode">
															<xsl:with-param name="part-code" select="catESAD_cu:PrecedingDocumentCustomsCode"/>
															<xsl:with-param name="part-date" select="catESAD_cu:PrecedingDocumentDate"/>
															<xsl:with-param name="part-number" select="catESAD_cu:PrecedingDocumentNumber"/>
														</xsl:call-template>
													</G402>
													<G32>
														<xsl:value-of select="../catESAD_cu:GoodsNumeric"/>
													</G32>
												</GTD40_ITEM>
											</xsl:for-each>
										</GTD40>
									</xsl:if>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:variable name="content-of-GTDBACK">
								<xsl:for-each select="catESAD_cu:GoodsDescription[position()>1]">
									<GTDBACK_ITEM>
										<G32>
											<xsl:value-of select="../catESAD_cu:GoodsNumeric"/>
										</G32>
										<GRAPH_NO>
											<xsl:value-of select="'31'"/>
										</GRAPH_NO>
										<TEXT>
											<xsl:value-of select="."/>
										</TEXT>
									</GTDBACK_ITEM>
								</xsl:for-each>
								<xsl:if test="catESAD_cu:GoodsNumeric=1">
									<xsl:copy-of select="$GTDBACK-NUM_PLOM"/>
								</xsl:if>
							</xsl:variable>
							<xsl:if test="string-length($content-of-GTDBACK)!=0">
								<GTDBACK>
									<xsl:copy-of select="$content-of-GTDBACK"/>
								</GTDBACK>
							</xsl:if>
						</VTTDOP_ITEM>
					</xsl:for-each>
				</VTTDOP>
				<xsl:for-each select="ESADout_CU:ESADout_CUGoodsShipment[1]/ESADout_CU:TDGuarantee[1]">
					<xsl:for-each select="catESAD_cu:MeasureCode[1]">
						<G52CODE>
							<xsl:value-of select="."/>
						</G52CODE>
					</xsl:for-each>
					<xsl:choose>
						<xsl:when test="catESAD_cu:GuaranteeTD">
							<xsl:for-each select="catESAD_cu:GuaranteeTD/catESAD_cu:GeneralNumber[1]">
								<GRNTGENERALNUM>
									<xsl:value-of select="."/>
								</GRNTGENERALNUM>
							</xsl:for-each>
							<xsl:for-each select="catESAD_cu:GuaranteeTD/catESAD_cu:GeneralDate[1]">
								<GRNTGENERALDATE>
									<xsl:value-of select="."/>
								</GRNTGENERALDATE>
							</xsl:for-each>
							<xsl:for-each select="catESAD_cu:GuaranteeTD/catESAD_cu:GuaranteeNumber[1]">
								<GRNTCONTRACTNUM>
									<xsl:value-of select="."/>
								</GRNTCONTRACTNUM>
							</xsl:for-each>
							<xsl:for-each select="catESAD_cu:GuaranteeTD/catESAD_cu:GuaranteeDate[1]">
								<GRNTCONTRACTDATE>
									<xsl:value-of select="."/>
								</GRNTCONTRACTDATE>
							</xsl:for-each>
							<xsl:for-each select="catESAD_cu:GuaranteeTD/catESAD_cu:AddGuaranteeNumber[1]">
								<G52DOC>
									<xsl:value-of select="."/>
								</G52DOC>
							</xsl:for-each>
							<xsl:for-each select="catESAD_cu:GuaranteeTD/catESAD_cu:AddGuaranteeDate[1]">
								<G52DATE>
									<xsl:value-of select="."/>
								</G52DATE>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<xsl:for-each select="catESAD_cu:DocNumber[1]">
								<G52DOC>
									<xsl:value-of select="."/>
								</G52DOC>
							</xsl:for-each>
							<xsl:for-each select="catESAD_cu:DocDate[1]">
								<G52DATE>
									<xsl:value-of select="."/>
								</G52DATE>
							</xsl:for-each>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
				<xsl:variable name="content-of-GTDDKD">
					<xsl:for-each select="$Consigment[1]">
						<xsl:for-each select="$DepartureArrival-ActiveTransportMeans[position()>1] | $DepartureArrival-TrailerTransportMeans[position()>2]">
							<GTDDKD_ITEM>
								<NGR>
									<xsl:value-of select="'18'"/>
								</NGR>
								<NTRANS>
									<xsl:value-of select="cat_ru:TransportIdentifier"/>
								</NTRANS>
							</GTDDKD_ITEM>
						</xsl:for-each>
						<xsl:for-each select="$Border-ActiveTransportMeans[position()>1] | $Border-TrailerTransportMeans[position()>2]">
							<GTDDKD_ITEM>
								<NGR>
									<xsl:value-of select="'21'"/>
								</NGR>
								<NTRANS>
									<xsl:value-of select="cat_ru:TransportIdentifier"/>
								</NTRANS>
							</GTDDKD_ITEM>
						</xsl:for-each>
					</xsl:for-each>
				</xsl:variable>
				<xsl:if test="string-length($content-of-GTDDKD)!=0">
					<GTDDKD>
						<xsl:copy-of select="$content-of-GTDDKD"/>
					</GTDDKD>
				</xsl:if>
			</VTTPRIM_ITEM>
		</VTTPRIM>
	</xsl:template>
	<xsl:template match="ESADout_CU:ESADout_CUConsignor">
		<xsl:for-each select="cat_ru:RFOrganizationFeatures[1]/cat_ru:OGRN[1]">
			<SENDEROGRN>
				<xsl:value-of select="."/>
			</SENDEROGRN>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:RFOrganizationFeatures[1]/cat_ru:INN[1]">
			<M021>
				<xsl:value-of select="."/>
			</M021>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:RFOrganizationFeatures[1]/cat_ru:KPP[1]">
			<KPP>
				<xsl:value-of select="."/>
			</KPP>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:OrganizationName[1]">
			<G022>
				<xsl:value-of select="."/>
			</G022>
		</xsl:for-each>
		<xsl:apply-templates select="//ESADout_CU:ESADout_CUConsignor/cat_ru:Address"/>
		<xsl:apply-templates select="//ESADout_CU:ESADout_CUConsignor/cat_ru:IdentityCard"/>
	</xsl:template>
	<xsl:template match="ESADout_CU:ESADout_CUConsignor/cat_ru:Address">
		<xsl:for-each select="cat_ru:City[1]">
			<G02_CITY>
				<xsl:value-of select="."/>
			</G02_CITY>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:CountryCode[1]">
			<G02_COUNTRYCODE>
				<xsl:value-of select="."/>
			</G02_COUNTRYCODE>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:CounryName[1]">
			<G02_COUNTRYNAME>
				<xsl:value-of select="."/>
			</G02_COUNTRYNAME>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:PostalCode[1]">
			<G02_POSTALCODE>
				<xsl:value-of select="."/>
			</G02_POSTALCODE>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:Region[1]">
			<G02_REGION>
				<xsl:value-of select="."/>
			</G02_REGION>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:StreetHouse[1]">
			<G02_STREETHOUSE>
				<xsl:value-of select="."/>
			</G02_STREETHOUSE>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="ESADout_CU:ESADout_CUConsignor/cat_ru:IdentityCard">
		<xsl:for-each select="cat_ru:IdentityCardCode[1]">
			<G02_PERSCARDCODE>
				<xsl:value-of select="."/>
			</G02_PERSCARDCODE>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:IdentityCardName[1]">
			<G02_PERSCARDNAME>
				<xsl:value-of select="."/>
			</G02_PERSCARDNAME>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:IdentityCardSeries[1]">
			<G02_PERSCARDSERIES>
				<xsl:value-of select="."/>
			</G02_PERSCARDSERIES>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:IdentityCardNumber[1]">
			<G02_PERSCARDNUM>
				<xsl:value-of select="."/>
			</G02_PERSCARDNUM>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:IdentityCardDate[1]">
			<G02_PERSCARDDATE>
				<xsl:value-of select="."/>
			</G02_PERSCARDDATE>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:OrganizationName[1]">
			<G02_PERSCARDORG>
				<xsl:value-of select="."/>
			</G02_PERSCARDORG>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="ESADout_CU:ESADout_CUConsignee">
		<xsl:for-each select="cat_ru:RFOrganizationFeatures[1]/cat_ru:OGRN[1]">
			<RECEIVOGRN>
				<xsl:value-of select="."/>
			</RECEIVOGRN>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:RFOrganizationFeatures[1]/cat_ru:INN[1]">
			<M081>
				<xsl:value-of select="."/>
			</M081>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:RFOrganizationFeatures[1]/cat_ru:KPP[1]">
			<KPP_RECEIV>
				<xsl:value-of select="."/>
			</KPP_RECEIV>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:OrganizationName[1]">
			<G082>
				<xsl:value-of select="."/>
			</G082>
		</xsl:for-each>
		<xsl:apply-templates select="//ESADout_CU:ESADout_CUConsignee/cat_ru:Address"/>
		<xsl:apply-templates select="//ESADout_CU:ESADout_CUConsignee/cat_ru:IdentityCard"/>
	</xsl:template>
	<xsl:template match="ESADout_CU:ESADout_CUConsignee/cat_ru:Address">
		<xsl:for-each select="cat_ru:City[1]">
			<G08_CITY>
				<xsl:value-of select="."/>
			</G08_CITY>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:CountryCode[1]">
			<G08_COUNTRYCODE>
				<xsl:value-of select="."/>
			</G08_COUNTRYCODE>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:CounryName[1]">
			<G08_COUNTRYNAME>
				<xsl:value-of select="."/>
			</G08_COUNTRYNAME>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:PostalCode[1]">
			<G08_POSTALCODE>
				<xsl:value-of select="."/>
			</G08_POSTALCODE>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:Region[1]">
			<G08_REGION>
				<xsl:value-of select="."/>
			</G08_REGION>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:StreetHouse[1]">
			<G08_STREETHOUSE>
				<xsl:value-of select="."/>
			</G08_STREETHOUSE>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="ESADout_CU:ESADout_CUConsignee/cat_ru:IdentityCard">
		<xsl:for-each select="cat_ru:IdentityCardCode[1]">
			<G08_PERSCARDCODE>
				<xsl:value-of select="."/>
			</G08_PERSCARDCODE>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:IdentityCardName[1]">
			<G08_PERSCARDNAME>
				<xsl:value-of select="."/>
			</G08_PERSCARDNAME>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:IdentityCardSeries[1]">
			<G08_PERSCARDSERIES>
				<xsl:value-of select="."/>
			</G08_PERSCARDSERIES>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:IdentityCardNumber[1]">
			<G08_PERSCARDNUM>
				<xsl:value-of select="."/>
			</G08_PERSCARDNUM>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:IdentityCardDate[1]">
			<G08_PERSCARDDATE>
				<xsl:value-of select="."/>
			</G08_PERSCARDDATE>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:OrganizationName[1]">
			<G08_PERSCARDORG>
				<xsl:value-of select="."/>
			</G08_PERSCARDORG>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="ESADout_CU:ESADout_CUDeclarant">
		<xsl:for-each select="cat_ru:RFOrganizationFeatures[1]/cat_ru:OGRN[1]">
			<FA_OGRN>
				<xsl:value-of select="."/>
			</FA_OGRN>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:RFOrganizationFeatures[1]/cat_ru:INN[1]">
			<FA_INN>
				<xsl:value-of select="."/>
			</FA_INN>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:RFOrganizationFeatures[1]/cat_ru:KPP[1]">
			<FA_KPP>
				<xsl:value-of select="."/>
			</FA_KPP>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:OrganizationName[1]">
			<FAGENTNAME>
				<xsl:value-of select="."/>
			</FAGENTNAME>
		</xsl:for-each>
		<xsl:apply-templates select="//ESADout_CU:ESADout_CUDeclarant/cat_ru:Address"/>
		<xsl:apply-templates select="cat_ru:IdentityCard"/>
	</xsl:template>
	<xsl:template match="ESADout_CU:ESADout_CUDeclarant/cat_ru:Address">
		<xsl:for-each select="cat_ru:City[1]">
			<FA_CITY>
				<xsl:value-of select="."/>
			</FA_CITY>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:CountryCode[1]">
			<FA_COUNTRYCODE>
				<xsl:value-of select="."/>
			</FA_COUNTRYCODE>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:CounryName[1]">
			<FA_COUNTRYNAME>
				<xsl:value-of select="."/>
			</FA_COUNTRYNAME>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:PostalCode[1]">
			<FA_POSTALCODE>
				<xsl:value-of select="."/>
			</FA_POSTALCODE>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:Region[1]">
			<FA_REGION>
				<xsl:value-of select="."/>
			</FA_REGION>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:StreetHouse[1]">
			<FA_STREETHOUSE>
				<xsl:value-of select="."/>
			</FA_STREETHOUSE>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="ESADout_CU:ESADout_CUDeclarant/cat_ru:IdentityCard">
		<xsl:for-each select="cat_ru:IdentityCardCode[1]">
			<FA_PERSCARDCODE>
				<xsl:value-of select="."/>
			</FA_PERSCARDCODE>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:IdentityCardName[1]">
			<FA_PERSCARDNAME>
				<xsl:value-of select="."/>
			</FA_PERSCARDNAME>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:IdentityCardSeries[1]">
			<FA_PERSCARDSERIES>
				<xsl:value-of select="."/>
			</FA_PERSCARDSERIES>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:IdentityCardNumber[1]">
			<FA_PERSCARDNUM>
				<xsl:value-of select="."/>
			</FA_PERSCARDNUM>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:IdentityCardDate[1]">
			<FA_PERSCARDDATE>
				<xsl:value-of select="."/>
			</FA_PERSCARDDATE>
		</xsl:for-each>
		<xsl:for-each select="cat_ru:OrganizationName[1]">
			<FA_PERSCARDORG>
				<xsl:value-of select="."/>
			</FA_PERSCARDORG>
		</xsl:for-each>
	</xsl:template>
</xsl:stylesheet>
