<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:import href="template-value.xsl"/>
	<xsl:template name="customs-number-encode">
		<xsl:param name="part-code"/>
		<xsl:param name="part-date"/>
		<xsl:param name="part-number"/>
		<xsl:if test="string-length($part-number)!=0">
			<xsl:value-of select="$part-code"/>
			<xsl:value-of select="'/'"/>
			<xsl:call-template name="customs-date">
				<xsl:with-param name="date-time" select="$part-date"/>
			</xsl:call-template>
			<xsl:value-of select="'/'"/>
			<xsl:value-of select="$part-number"/>
		</xsl:if>
	</xsl:template>
	<xsl:template name="customs-date">
		<xsl:param name="date-time"/>
		<!-- 2007-12-27T00:00:00+01:00-->
		<!--ddMMyy-->
		<xsl:choose>
			<xsl:when test="string-length(translate($date-time,'-',''))+2 = string-length($date-time)">
				<!--$date-time='2007-12-27T00:00:00+01:00'-->
				<!--output format ddMMyy-->
				<xsl:value-of select="substring($date-time,9,2)"/>
				<xsl:value-of select="substring($date-time,6,2)"/>
				<xsl:value-of select="substring($date-time,3,2)"/>
			</xsl:when>
			<xsl:otherwise>
				<!--$date-time='ddMMyy' (КПС Транзитные операции, bug 18145)-->
				<!--output = input-->
				<xsl:value-of select="substring($date-time,1,6)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="customs-number-elements">
		<xsl:param name="whole-number"/>
		<xsl:param name="element1-name"/>
		<xsl:param name="element2-name"/>
		<xsl:param name="element3-name"/>
		<xsl:param name="namespace-context"/>
		<xsl:param name="customs-date-decoded" select="true()"/>
		<xsl:variable name="namespace">
			<xsl:call-template name="namespace-of-name">
				<xsl:with-param name="element-name" select="$element3-name"/>
				<xsl:with-param name="namespace-context" select="$namespace-context"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="contains($whole-number, '/') and contains(substring-after($whole-number, '/'), '/')">
				<xsl:element name="{$element1-name}" namespace="{$namespace}">
					<xsl:value-of select="substring-before($whole-number, '/')"/>
				</xsl:element>
				<xsl:element name="{$element2-name}" namespace="{$namespace}">
					<xsl:variable name="customs-date" select="substring-before(substring-after($whole-number, '/'), '/')"/>
					<xsl:choose>
						<xsl:when test="$customs-date-decoded">
							<xsl:call-template name="customs-date-decoded">
								<xsl:with-param name="customs-date" select="$customs-date"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$customs-date"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="{$element3-name}" namespace="{$namespace}">
					<xsl:value-of select="substring-after(substring-after($whole-number, '/'), '/')"/>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name="{$element3-name}" namespace="{$namespace}">
					<xsl:value-of select="$whole-number"/>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="customs-date-decoded">
		<xsl:param name="customs-date"/>
		<!--ddMMyy, ddMMy-->
		<!-- 2007-12-27T00:00:00+01:00-->
		<xsl:choose>
			<xsl:when test="string-length($customs-date)&lt;5">
				<!--пример даты в нероссийском номере 123807070001/2011/127264 (Украина?)
таможенная загрузка просто берёт строку без понятия формата даты-->
				<xsl:value-of select="$customs-date"/>
			</xsl:when>
			<xsl:when test="string-length($customs-date)>4">
				<xsl:value-of select="'20'"/>
				<xsl:if test="string-length($customs-date)=5">
					<xsl:value-of select="'1'">
						<!--текущее десятилетие - пока ещё 2010 гг. - добавляем, когда есть только одна цифра года - в пятизначной дате-->
					</xsl:value-of>
				</xsl:if>
				<xsl:value-of select="substring($customs-date,5,2)"/>
				<xsl:value-of select="'-'"/>
				<xsl:value-of select="substring($customs-date,3,2)"/>
				<xsl:value-of select="'-'"/>
				<xsl:value-of select="substring($customs-date,1,2)"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="customs-text250">
		<xsl:param name="text"/>
		<xsl:param name="element-name"/>
		<xsl:param name="namespace-context"/>
		<xsl:param name="namespace">
			<xsl:call-template name="namespace-of-name">
				<xsl:with-param name="element-name" select="$element-name"/>
				<xsl:with-param name="namespace-context" select="$namespace-context"/>
			</xsl:call-template>
		</xsl:param>
		<xsl:element name="{$element-name}" namespace="{$namespace}">
			<xsl:value-of select="substring($text, 1, 250)"/>
		</xsl:element>
		<xsl:if test="string-length($text) > 250">
			<xsl:call-template name="customs-text250">
				<xsl:with-param name="text" select="substring($text, 251)"/>
				<xsl:with-param name="element-name" select="$element-name"/>
				<xsl:with-param name="namespace" select="$namespace"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
