<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:variable name="up-case-rus" select="'АБВГДЕЁЖЗИКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ'"/>
	<xsl:variable name="lo-case-rus" select="'абвгдеёжзиклмнопрстуфхцчшщъыьэюя'"/>
	<xsl:template name="boolean-from-string">
		<xsl:choose>
			<xsl:when test=".=number(true()) or .=string(true())">
				<xsl:value-of select="1"/>
			</xsl:when>
			<xsl:when test=".=number(false()) or .=string(false())">
				<xsl:value-of select="0"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="fix-float">
		<xsl:param name="float-number"/>
		<xsl:param name="round-factor" select="1000000"/>
		<xsl:if test="string-length($float-number)!=0">
			<xsl:value-of select="round(number($float-number) * $round-factor) div $round-factor"/>
			<!--Проблема выгрузки из СТМ-Конвертер дробных чисел: даёт 41593.300000000003 вместо 41593.3. Чтобы решить это, округляем здесь до 6 знаков, это достаточная точность для таможенных документов.
Хорошо бы вынести это в отдельный этап преобразования, чтобы освободить сущностное преобразование структуры от необходимости этих вызовов-->
		</xsl:if>
	</xsl:template>
	<xsl:template name="concat-delimited">
		<xsl:param name="prefix"/>
		<xsl:param name="string1"/>
		<xsl:param name="delimiter1"/>
		<xsl:param name="string2"/>
		<xsl:param name="delimiter2"/>
		<xsl:param name="string3"/>
		<xsl:param name="delimiter3"/>
		<xsl:param name="string4"/>
		<xsl:param name="delimiter4"/>
		<xsl:param name="string5"/>
		<xsl:param name="delimiter5"/>
		<xsl:param name="string6"/>
		<xsl:param name="delimiter6"/>
		<xsl:param name="string7"/>
		<xsl:param name="delimiter7"/>
		<xsl:param name="string8"/>
		<xsl:param name="delimiter8"/>
		<xsl:param name="string9"/>
		<xsl:param name="delimiter9"/>
		<xsl:param name="string10"/>
		<xsl:param name="postfix"/>
		<xsl:param name="recursion" select="(10-1)"/>
		<xsl:if test="(10>$recursion) and ($recursion>0)">
			<xsl:variable name="delimited-result">
				<xsl:variable name="remaining">
					<xsl:call-template name="concat-delimited">
						<xsl:with-param name="string1" select="$string2"/>
						<xsl:with-param name="delimiter1" select="$delimiter2"/>
						<xsl:with-param name="string2" select="$string3"/>
						<xsl:with-param name="delimiter2" select="$delimiter3"/>
						<xsl:with-param name="string3" select="$string4"/>
						<xsl:with-param name="delimiter3" select="$delimiter4"/>
						<xsl:with-param name="string4" select="$string5"/>
						<xsl:with-param name="delimiter4" select="$delimiter5"/>
						<xsl:with-param name="string5" select="$string6"/>
						<xsl:with-param name="delimiter5" select="$delimiter6"/>
						<xsl:with-param name="string6" select="$string7"/>
						<xsl:with-param name="delimiter6" select="$delimiter7"/>
						<xsl:with-param name="string7" select="$string8"/>
						<xsl:with-param name="delimiter7" select="$delimiter8"/>
						<xsl:with-param name="string8" select="$string9"/>
						<xsl:with-param name="delimiter8" select="$delimiter9"/>
						<xsl:with-param name="string9" select="$string10"/>
						<xsl:with-param name="recursion" select="($recursion)-1"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:value-of select="$string1"/>
				<xsl:if test="(string-length($string1)!=0) and (string-length($remaining)!=0)">
					<xsl:value-of select="$delimiter1"/>
				</xsl:if>
				<xsl:value-of select="$remaining"/>
			</xsl:variable>
			<xsl:if test="string-length($delimited-result)!=0">
				<xsl:value-of select="$prefix"/>
			</xsl:if>
			<xsl:value-of select="$delimited-result"/>
			<xsl:if test="string-length($delimited-result)!=0">
				<xsl:value-of select="$postfix"/>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	<xsl:template name="split-string">
		<xsl:param name="delimited-string"/>
		<xsl:param name="delimeter" select="','"/>
		<xsl:param name="element-name"/>
		<xsl:param name="namespace-context"/>
		<xsl:variable name="namespace">
			<xsl:call-template name="namespace-of-name">
				<xsl:with-param name="element-name" select="$element-name"/>
				<xsl:with-param name="namespace-context" select="$namespace-context"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="has-delimiter" select="contains($delimited-string, $delimeter)"/>
		<xsl:element name="{$element-name}" namespace="{$namespace}">
			<xsl:choose>
				<xsl:when test="$has-delimiter">
					<xsl:value-of select="substring-before($delimited-string, $delimeter)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$delimited-string"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:element>
		<xsl:if test="$has-delimiter">
			<xsl:call-template name="split-string">
				<xsl:with-param name="element-name" select="$element-name"/>
				<xsl:with-param name="namespace-context" select="$namespace-context"/>
				<xsl:with-param name="delimited-string" select="substring-after($delimited-string, $delimeter)"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<xsl:template name="namespace-of-name">
		<xsl:param name="element-name"/>
		<xsl:param name="namespace-context"/>
		<xsl:variable name="prefix" select="substring-before($element-name, ':')"/>
		<xsl:value-of select="string($namespace-context//namespace::*[name()=$prefix])"/>
		<!--<xsl:value-of select="string($namespace-context//namespace::*[name()='#default'])"/>-->
	</xsl:template>
	<xsl:template name="date-but-time">
		<xsl:param name="date-time"/>
		<xsl:value-of select="substring-before($date-time,'T')"/>
	</xsl:template>
	<xsl:template name="time-from-string">
		<!--input='12:34', output='12:34:00'-->
		<xsl:param name="time-as-string"/>
		<xsl:if test="string-length($time-as-string)">
			<xsl:value-of select="substring($time-as-string, 1, 2)"/>
			<xsl:value-of select="':'"/>
			<xsl:value-of select="substring($time-as-string, 4, 2)"/>
			<xsl:value-of select="':00'"/>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
